@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     zhuyuliang <zhuyuliang@uniontech.com>
- *
- * Maintainer: zhuyuliang <zhuyuliang@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "config.h"
 
 #include "mpv_proxy.h"
@@ -404,8 +376,10 @@ namespace dmr {
 
 #ifdef _LIBDMR_
         if(utils::check_wayland_env()){
+            m_bDoRoundedClipping = false;
             toggleRoundedClip(true);
         }else{
+            m_bDoRoundedClipping = true;
             toggleRoundedClip(false);
         }
 #else
@@ -413,6 +387,9 @@ namespace dmr {
         connect(window()->windowHandle(), &QWindow::windowStateChanged, [=]() {
             QWidget* pTopWid = this->topLevelWidget();
             bool rounded = !pTopWid->isFullScreen() && !pTopWid->isMaximized();
+            // 全屏和最大化下不裁剪圆角
+            m_bDoRoundedClipping = rounded;
+
             if(utils::check_wayland_env()){
                 toggleRoundedClip(true);
             } else {
@@ -425,7 +402,7 @@ namespace dmr {
 
     void QtPlayerGLWidget::updateMovieFbo()
     {
-        if (!m_bDoRoundedClipping) return;
+        if (!m_bUseCustomFBO) return;
 
         auto desiredSize = size() * qApp->devicePixelRatio();
 
@@ -441,7 +418,7 @@ namespace dmr {
 
     void QtPlayerGLWidget::updateCornerMasks()
     {
-        if (!utils::check_wayland_env() && !m_bDoRoundedClipping) return;
+        if (!utils::check_wayland_env() && !m_bUseCustomFBO) return;
 
         for (int i = 0; i < 4; i++) {
             QSize sz(RADIUS, RADIUS);
@@ -644,7 +621,7 @@ namespace dmr {
         updateMovieFbo();
         updateVbo();
         updateVboBlend();
-        if (m_bDoRoundedClipping){
+        if (m_bUseCustomFBO){
             updateVboCorners();
         }
         qInfo() << "GL resize" << nWidth << nHeight;
@@ -653,7 +630,9 @@ namespace dmr {
 
     void QtPlayerGLWidget::toggleRoundedClip(bool bFalse)
     {
-        m_bDoRoundedClipping = bFalse;
+        // 设置圆角时使用自定的FBO，但在全屏和最大化时，通过
+        // m_bDoRoundedClipping 设置是否实际应用圆角
+        m_bUseCustomFBO = bFalse;
         makeCurrent();
         updateMovieFbo();
         update();
@@ -664,7 +643,8 @@ namespace dmr {
         m_bPlaying = false;
         m_bInMiniMode= false;
 
-        m_bDoRoundedClipping=true;
+        m_bUseCustomFBO = true;
+        m_bDoRoundedClipping = true;
         m_pDarkTex = nullptr;
         m_pLightTex = nullptr;
         m_pGlProg = nullptr;
@@ -839,7 +819,8 @@ namespace dmr {
     {
         if(!m_pVideoTex){
             QFileInfo fi("/dev/mwv206_0");
-            if (fi.exists()) {
+            QFileInfo jmfi("/dev/jmgpu");
+            if (fi.exists() || jmfi.exists()) {
                 m_pVideoTex = new QOpenGLTexture(image, QOpenGLTexture::DontGenerateMipMaps);
             } else {
                 m_pVideoTex = new QOpenGLTexture(image, QOpenGLTexture::GenerateMipMaps);
