@@ -1,40 +1,13 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     xiepengfei <xiepengfei@uniontech.com>
- *
- * Maintainer: xiepengfei <xiepengfei@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "config.h"
 
 #include "mpv_proxy.h"
 #include "mpv_glwidget.h"
+#include "sysutils.h"
 
 #include <QtX11Extras/QX11Info>
 #include <QLibrary>
@@ -42,6 +15,7 @@
 
 #include <dthememanager.h>
 #include <DApplication>
+#include <QDBusInterface>
 //#include <wayland-client.h>
 //#include "../../window/qplatformnativeinterface.h"
 //qpa/qplatformnativeinterface.h
@@ -61,6 +35,11 @@ DWIDGET_USE_NAMESPACE
 #endif
 
 static const char *vs_blend = R"(
+#ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
+precision mediump float;
+#endif
 attribute vec2 position;
 attribute vec2 vTexCoord;
 
@@ -73,6 +52,11 @@ void main() {
 )";
 
 static const char* fs_blend = R"(
+#ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
+precision mediump float;
+#endif
 varying vec2 texCoord;
 
 uniform sampler2D movie;
@@ -84,6 +68,8 @@ void main() {
 
 static const char* fs_blend_wayland = R"(
 #ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
 precision mediump float;
 #endif
 varying vec2 texCoord;
@@ -96,6 +82,11 @@ void main() {
 )";
 
 static const char* vs_blend_corner = R"(
+#ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
+precision mediump float;
+#endif
 attribute vec2 position;
 attribute vec2 maskTexCoord;
 attribute vec2 vTexCoord;
@@ -111,6 +102,11 @@ void main() {
 )";
 
 static const char* fs_blend_corner = R"(
+#ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
+precision mediump float;
+#endif
 varying vec2 maskCoord;
 varying vec2 texCoord;
 
@@ -124,6 +120,8 @@ void main() {
 
 static const char* fs_blend_corner_wayland = R"(
 #ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
 precision mediump float;
 #endif
 varying vec2 maskCoord;
@@ -138,6 +136,12 @@ void main() {
 )";
 
 static const char* vs_code = R"(
+#ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
+precision mediump float;
+#endif
+
 attribute vec2 position;
 attribute vec2 vTexCoord;
 
@@ -150,6 +154,11 @@ void main() {
 )";
 
 static const char* fs_code = R"(
+#ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
+precision mediump float;
+#endif
 varying vec2 texCoord;
 
 uniform sampler2D sampler;
@@ -163,6 +172,8 @@ void main() {
 
 static const char* fs_code_wayland = R"(
 #ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
 precision mediump float;
 #endif
 varying vec2 texCoord;
@@ -177,6 +188,11 @@ void main() {
 )";
 
 static const char* fs_corner_code = R"(
+#ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
+precision mediump float;
+#endif
 varying vec2 texCoord;
 
 uniform sampler2D corner;
@@ -190,6 +206,8 @@ void main() {
 
 static const char* fs_corner_code_wayland = R"(
 #ifdef GL_ES
+// Set default precision to medium
+precision mediump int;
 precision mediump float;
 #endif
 varying vec2 texCoord;
@@ -477,7 +495,12 @@ namespace dmr {
         if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()){
             a = static_cast<float>(252.0 / 255.0);
         }
-        pGLFunction->glClearColor(a, a, a, 1.0);
+        if(parent()->property("color").isValid()) {
+            QColor clr = parent()->property("color").value<QColor>();
+            pGLFunction->glClearColor(clr.red()/255.f, clr.green()/255.f, clr.blue()/255.f, 1.0);
+        } else {
+            pGLFunction->glClearColor(a, a, a, 1.0);
+        }
 
         prepareSplashImages();
         setupIdlePipe();
@@ -485,8 +508,10 @@ namespace dmr {
 
 #ifdef _LIBDMR_
         if(utils::check_wayland_env()){
+            m_bDoRoundedClipping = true;
             toggleRoundedClip(true);
         }else{
+            m_bDoRoundedClipping = false;
             toggleRoundedClip(false);
         }
 #else
@@ -494,11 +519,14 @@ namespace dmr {
         connect(window()->windowHandle(), &QWindow::windowStateChanged, [=]() {
             QWidget* pTopWid = this->topLevelWidget();
             bool rounded = !pTopWid->isFullScreen() && !pTopWid->isMaximized();
-            if(utils::check_wayland_env()){
-                toggleRoundedClip(true);
-            } else {
-                toggleRoundedClip(rounded);
+            // 全屏和最大化下不裁剪圆角
+            m_bDoRoundedClipping = rounded;
+
+            //wayland
+            if(utils::check_wayland_env()) {
+                rounded = true;
             }
+            toggleRoundedClip(rounded);
         });
 #endif
 #endif
@@ -541,7 +569,7 @@ namespace dmr {
 
     void MpvGLWidget::updateMovieFbo()
     {
-        if (!m_bDoRoundedClipping) return;
+        if (!m_bUseCustomFBO) return;
 
         auto desiredSize = size() * qApp->devicePixelRatio();
 
@@ -557,7 +585,7 @@ namespace dmr {
 
     void MpvGLWidget::updateCornerMasks()
     {
-        if (!utils::check_wayland_env() && !m_bDoRoundedClipping) return;
+        if (!utils::check_wayland_env() && !m_bUseCustomFBO) return;
 
         for (int i = 0; i < 4; i++) {
             QSize sz(RADIUS, RADIUS);
@@ -739,7 +767,7 @@ namespace dmr {
 
         updateMovieFbo();
         updateVbo();
-        if (m_bDoRoundedClipping){
+        if (m_bUseCustomFBO){
             updateVboCorners();
         }
         qInfo() << "GL resize" << nWidth << nHeight;
@@ -748,7 +776,9 @@ namespace dmr {
 
     void MpvGLWidget::toggleRoundedClip(bool bFalse)
     {
-        m_bDoRoundedClipping = bFalse;
+        // 设置圆角时使用自定的FBO，但在全屏和最大化时，通过
+        // m_bDoRoundedClipping 设置是否实际应用圆角
+        m_bUseCustomFBO = bFalse;
         makeCurrent();
         updateMovieFbo();
         update();
@@ -761,7 +791,8 @@ namespace dmr {
         m_bPlaying = false;
         m_bInMiniMode= false;
 
-        m_bDoRoundedClipping=true;
+        m_bUseCustomFBO = true;
+        m_bDoRoundedClipping = true;
         m_pDarkTex = nullptr;
         m_pLightTex = nullptr;
         m_pGlProg = nullptr;
@@ -798,7 +829,7 @@ namespace dmr {
             QSize scaled = size() * dpr;
             int nFlip = 1;
 
-            if (!m_bDoRoundedClipping) {
+            if (!m_bUseCustomFBO) {
                 mpv_opengl_fbo fbo {
                     static_cast<int>(defaultFramebufferObject()), scaled.width(), scaled.height(), 0
                 };
@@ -935,7 +966,12 @@ namespace dmr {
                 color = QColor(252, 252, 252, 255);
                 fRation = 252.0f / 255.0f;
             }
-            pGLFunction->glClearColor(fRation, fRation, fRation, 1.0);
+            if(parent()->property("color").isValid()) {
+                QColor clr = parent()->property("color").value<QColor>();
+                pGLFunction->glClearColor(clr.red()/255.f, clr.green()/255.f, clr.blue()/255.f, 1.0);
+            } else {
+                pGLFunction->glClearColor(fRation, fRation, fRation, 1.0);
+            }
             pGLFunction->glClear(GL_COLOR_BUFFER_BIT);
 
             for(int i = 0;i < 2 ;i ++){
@@ -1037,7 +1073,7 @@ namespace dmr {
     void MpvGLWidget::initMpvFuns()
     {
         qInfo() << "MpvGLWidget开始initMpvFuns";
-        QLibrary mpvLibrary(libPath("libmpv.so.1"));
+        QLibrary mpvLibrary(SysUtils::libPath("libmpv.so"));
         m_callback = reinterpret_cast<mpv_render_contextSet_update_callback>(mpvLibrary.resolve("mpv_render_context_set_update_callback"));
         m_context_report = reinterpret_cast<mpv_render_contextReport_swap>(mpvLibrary.resolve("mpv_render_context_report_swap"));
         m_renderContex = reinterpret_cast<mpv_renderContext_free>(mpvLibrary.resolve("mpv_render_context_free"));
