@@ -1,32 +1,7 @@
-/*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef _DMR_MAIN_WINDOW_H
 #define _DMR_MAIN_WINDOW_H
 
@@ -48,6 +23,7 @@
 #include "actions.h"
 #include "online_sub.h"
 #include "compositing_manager.h"
+#include "mircastshowwidget.h"
 
 class Presenter;
 
@@ -247,6 +223,10 @@ signals:
      * @brief 字幕菜单是否可用信号
      */
     void subtitleMenuEnable(bool);
+    /**
+     * @brief soundMenuEnable 声音字幕是否可用信号
+     */
+    void soundMenuEnable(bool);
     /**
      * @brief 窗口特效变化信号
      */
@@ -355,6 +335,9 @@ public slots:
      */
     void play(const QList<QString> &listFiles);
     void slotFinishedAddFiles(QList<QUrl>);
+    /**
+     * @brief 该函数主要设置 m_pToolbox 和 m_pPlaylist 的Geometry，在(初始化)、(紧凑/正常终模式之间切换时)以及(全屏/非全屏模式之间切换时）调用
+     */
     void updateProxyGeometry();
     void suspendToolsWindow();
     void resumeToolsWindow();
@@ -409,8 +392,17 @@ public slots:
      * @brief 音量改变槽函数
      */
     void slotVolumeChanged(int nVolume);
-    void slotWMChanged(QString msg);
+    void slotWMChanged();
     void slotMediaError();
+    /**
+     * @brief slotUpdateMircastState 更新投屏状态槽函数
+     * @param state 投屏状态
+     */
+    void slotUpdateMircastState(int state, QString msg);
+    /**
+     * @brief slotExitMircast 退出投屏槽函数
+     */
+    void slotExitMircast();
 
 protected:
     void showEvent(QShowEvent *pEvent) override;
@@ -502,6 +494,16 @@ private:
     void setPlaySpeedMenuChecked(ActionFactory::ActionKind);
     void setPlaySpeedMenuUnchecked();
     void setMusicShortKeyState(bool bState);
+    /**
+     * @brief mircastSuccess 投屏成功更新界面
+     */
+    void mircastSuccess(QString name);
+    void exitMircast();
+
+    /**
+     * @brief 使用dbus获取当前机器CPU型号
+     */
+    QString cpuHardwareByDBus();
 
 private:
     MessageWindow *m_pPopupWid;                     ///截图提示窗口
@@ -524,6 +526,7 @@ private:
     QImage m_imgBgLight;
     bool m_bMiniMode;                               ///记录迷你模式
     QRect m_lastRectInNormalMode;                   /// used to restore to recent geometry when quit fullscreen or minVolumeMonitoringi mode
+    QRect m_waylandRectInNormalMode;                /// wayland下记录切换迷你模式前默认窗口状态
     bool m_bInited;                                 /// the first time a play happens, we consider it inited.
     EventMonitor *m_pEventMonitor;                  ///x11事件处理器
     bool m_bMovieSwitchedInFsOrMaxed;               /// track if next/prev is triggered in fs/maximized mode
@@ -577,13 +580,14 @@ private:
     QDBusInterface *m_pDBus;
     Presenter *m_pPresenter;
     MovieWidget *m_pMovieWidget;
+    MircastShowWidget *m_pMircastShowWidget;          ///投屏展示界面
     qint64 m_nFullscreenTime;                         ///全屏操作间隔时间
-    QDBusInterface *m_pWMDBus {nullptr};              ///窗口特效dbus接口
     bool m_bIsWM {true};                              ///是否开启窗口特效
     bool m_isSettingMiniMode{false};                  ///mini mode setting status
     Qt::WindowStates m_preMiniWindowState {Qt::WindowNoState};  ///window state before mini mode
     bool m_bMaximized;                                ///全屏前最大化窗口记录
     bool m_bHaveFile;                                 ///导入是否包含文件（用于导入文件或文件夹）
+    DSettingsDialog *m_pDSettingDilog{nullptr};
 };
 };
 
