@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     xiepengfei <xiepengfei@uniontech.com>
- *
- * Maintainer: liuzheng <liuzheng@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "config.h"
 #include "movie_configuration.h"
 #include "utils.h"
@@ -70,7 +42,10 @@ public:
         auto db_path = QString("%1/movies.db").arg(db_dir);
         _db = QSqlDatabase::addDatabase("QSQLITE");
         _db.setDatabaseName(db_path);
-        _db.open();
+        if(!_db.open()) {
+            qCritical() << "open the movies database error";
+            return;
+        }
 
         auto ts = _db.tables(QSql::Tables);
         if (!ts.contains("urls") || !ts.contains("infos")) {
@@ -89,81 +64,96 @@ public:
 
     void deleteUrl(const QUrl &url)
     {
-        _db.transaction();
+        if(_db.transaction()) {
+            QSqlQuery q(_db);
+            if(q.prepare("delete from infos where url = ?")) {
+                q.addBindValue(url);
+                if (!q.exec()) {
+                    if(!_db.commit()) {
+                        qCritical() << _db.lastError();
+                    }
+                    return;
+                }
+            }
 
-        QSqlQuery q(_db);
-        q.prepare("delete from infos where url = ?");
-        q.addBindValue(url);
-        if (!q.exec()) {
-            _db.commit();
-            return;
-        }
-
-        if (q.numRowsAffected() > 0) {
-            QSqlQuery q_l(_db);
-            q_l.prepare("delete from urls where url = ?");
-            q_l.addBindValue(url);
-            CHECKED_EXEC(q_l);
+            if (q.numRowsAffected() > 0) {
+                QSqlQuery q_l(_db);
+                if(q_l.prepare("delete from urls where url = ?")) {
+                    q_l.addBindValue(url);
+                    CHECKED_EXEC(q_l);
+                }
+            }
         }
     }
 
     bool urlExists(const QUrl &url)
     {
         QSqlQuery q(_db);
-        q.prepare("select url from urls where url = ? limit 1");
-        q.addBindValue(url);
-        CHECKED_EXEC(q);
+        if(q.prepare("select url from urls where url = ? limit 1")) {
+            q.addBindValue(url);
+            CHECKED_EXEC(q);
+        }
 
         return q.first();
     }
 
     void clear()
     {
-        _db.transaction();
+        if(_db.transaction()) {
+            QSqlQuery q(_db);
+            if (q.exec("delete from infos")) {
+                if (q.exec("delete from urls")) {
+                    if(!_db.commit()) {
+                        qCritical() << _db.lastError();
+                    }
+                    return;
+                }
+            }
 
-        QSqlQuery q(_db);
-        if (q.exec("delete from infos")) {
-            if (q.exec("delete from urls")) {
-                _db.commit();
-                return;
+            if(!_db.rollback()) {
+                qCritical() << _db.lastError();
             }
         }
-
-        _db.rollback();
     }
 
     void updateUrl(const QUrl &url, const QString &key, const QVariant &val)
     {
         qInfo() << url << key << val;
 
-        _db.transaction();
+        if(_db.transaction()) {
+            if (!urlExists(url)) {
+                QString md5;
+                if (url.isLocalFile()) {
+                    md5 = utils::FastFileHash(QFileInfo(url.toLocalFile()));
+                } else {
+                    md5 = QString(QCryptographicHash::hash(url.toString().toUtf8(), QCryptographicHash::Md5).toHex());
+                }
 
-        if (!urlExists(url)) {
-            QString md5;
-            if (url.isLocalFile()) {
-                md5 = utils::FastFileHash(QFileInfo(url.toLocalFile()));
-            } else {
-                md5 = QString(QCryptographicHash::hash(url.toString().toUtf8(), QCryptographicHash::Md5).toHex());
+                QSqlQuery q(_db);
+                if(q.prepare("insert into urls (url, md5, timestamp) values (?, ?, ?)")) {
+                    q.addBindValue(url);
+                    q.addBindValue(md5);
+                    q.addBindValue(QDateTime::currentDateTimeUtc());
+                    if (!q.exec()) {
+                        if(!_db.rollback()) {
+                            qCritical() << _db.lastError();
+                        }
+                        return;
+                    }
+                }
             }
 
             QSqlQuery q(_db);
-            q.prepare("insert into urls (url, md5, timestamp) values (?, ?, ?)");
-            q.addBindValue(url);
-            q.addBindValue(md5);
-            q.addBindValue(QDateTime::currentDateTimeUtc());
-            if (!q.exec()) {
-                _db.rollback();
-                return;
+            if(q.prepare("replace into infos (url, key, value) values (?, ?, ?)")) {
+                q.addBindValue(url);
+                q.addBindValue(key);
+                q.addBindValue(val);
+                CHECKED_EXEC(q);
+                if(!_db.commit()) {
+                    qCritical() << _db.lastError();
+                }
             }
         }
-
-        QSqlQuery q(_db);
-        q.prepare("replace into infos (url, key, value) values (?, ?, ?)");
-        q.addBindValue(url);
-        q.addBindValue(key);
-        q.addBindValue(val);
-        CHECKED_EXEC(q);
-        _db.commit();
     }
 
     QVariant queryValueByUrlKey(const QUrl &url, const QString &key)
@@ -172,13 +162,14 @@ public:
             return {};
 
         QSqlQuery q(_db);
-        q.prepare("select value from infos where url = ? and key = ?");
-        q.addBindValue(url);
-        q.addBindValue(key);
-        CHECKED_EXEC(q);
+        if(q.prepare("select value from infos where url = ? and key = ?")) {
+            q.addBindValue(url);
+            q.addBindValue(key);
+            CHECKED_EXEC(q);
 
-        if (q.next()) {
-            return q.value(0);
+            if (q.next()) {
+                return q.value(0);
+            }
         }
 
         return QVariant();
@@ -190,9 +181,10 @@ public:
             return {};
 
         QSqlQuery q(_db);
-        q.prepare("select key, value from infos where url = ?");
-        q.addBindValue(url);
-        CHECKED_EXEC(q);
+        if(q.prepare("select key, value from infos where url = ?")) {
+            q.addBindValue(url);
+            CHECKED_EXEC(q);
+        }
 
         QMap<QString, QVariant> res;
         while (q.next()) {
@@ -260,7 +252,7 @@ void MovieConfiguration::append2ListUrl(const QUrl &url, KnownKey key, const QSt
 void MovieConfiguration::removeFromListUrl(const QUrl &url, KnownKey key, const QString &val)
 {
     ///add for warning by xxj ,no any means
-    val.isNull();
+    //val.isNull();
     auto list = getListByUrl(url, key);
 }
 
