@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     fengli <fengli@uniontech.com>
- *
- * Maintainer: xiepengfei <xiepengfei@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "config.h"
 #include <iostream>
 #include "player_engine.h"
@@ -53,6 +25,8 @@
 #include "drecentmanager.h"
 DCORE_USE_NAMESPACE
 DGUI_USE_NAMESPACE
+#define AV_CODEC_ID_AVS2 192
+#define AV_CODEC_ID_AVS3 193
 
 namespace dmr {
 
@@ -684,6 +658,7 @@ void PlayerEngine::playSelected(int id)
 void PlayerEngine::clearPlaylist()
 {
     _playlist->clear();
+    MovieConfiguration::get().clear();
 }
 
 void PlayerEngine::pauseResume()
@@ -767,7 +742,7 @@ bool PlayerEngine::addPlayFile(const QUrl &url)
     if (!isPlayableFile(realUrl))
         return false;
 
-    _playlist->append({realUrl});
+    _playlist->append(realUrl);
     return true;
 }
 
@@ -987,7 +962,11 @@ bool PlayerEngine::currFileIsAudio()
     }
 
     if (CompositingManager::isMpvExists()) {
-        bAudio = pif.thumbnail.isNull() && pif.url.isLocalFile();
+        if(pif.mi.vCodecID == AV_CODEC_ID_AVS2 || pif.mi.vCodecID == AV_CODEC_ID_AVS3) {
+            bAudio = false;
+        } else {
+            bAudio = pif.url.isLocalFile() && (pif.mi.width <= 0 && pif.mi.height <= 0);
+        }
     } else {
         bAudio = isAudioFile(pif.url.toString());
     }
