@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     zhuyuliang <zhuyuliang@uniontech.com>
- *
- * Maintainer: xiepengfei <xiepengfei@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "playlist_model.h"
 #include "player_engine.h"
 #include "utils.h"
@@ -40,11 +12,13 @@
 #include "dvd_utils.h"
 #include "compositing_manager.h"
 #include "gstutils.h"
+#include "sysutils.h"
 
 #include <QSvgRenderer>
 
 #include <random>
 extern "C" {
+#include <libavcodec/avcodec.h>
 #include <libavformat/avformat.h>
 #include <libavutil/dict.h>
 #include <libavutil/avutil.h>
@@ -60,6 +34,8 @@ typedef AVCodec *(*mvideo_avcodec_find_decoder)(enum AVCodecID id);
 typedef const char *(*mvideo_av_get_media_type_string)(enum AVMediaType media_type);
 typedef AVCodecContext *(*mvideo_avcodec_alloc_context3)(const AVCodec *codec);
 typedef int (*mvideo_avcodec_parameters_to_context)(AVCodecContext *codec, const AVCodecParameters *par);
+typedef int (*mvideo_avcodec_open2)(AVCodecContext *avctx, const AVCodec *codec, AVDictionary **options);
+typedef void (*mvideo_avcodec_free_context)(AVCodecContext **avctx);
 
 
 mvideo_avformat_open_input g_mvideo_avformat_open_input = nullptr;
@@ -72,6 +48,8 @@ mvideo_avcodec_find_decoder g_mvideo_avcodec_find_decoder = nullptr;
 mvideo_av_get_media_type_string g_mvideo_av_get_media_type_string = nullptr;
 mvideo_avcodec_alloc_context3 g_mvideo_avcodec_alloc_context3 = nullptr;
 mvideo_avcodec_parameters_to_context g_mvideo_avcodec_parameters_to_context = nullptr;
+mvideo_avcodec_open2 g_mvideo_avcodec_open2 = nullptr;
+mvideo_avcodec_free_context g_mvideo_avcodec_free_context = nullptr;
 
 namespace dmr {
 QDataStream &operator<< (QDataStream &st, const MovieInfo &mi)
@@ -338,6 +316,15 @@ struct MovieInfo PlaylistModel::parseFromFile(const QFileInfo &fi, bool *ok)
         } else {
             mi.proportion = 0;
         }
+
+        AVCodecContext *codec_context = g_mvideo_avcodec_alloc_context3(NULL);
+        g_mvideo_avcodec_parameters_to_context(codec_context, video_dec_ctx);
+        AVCodec *videoCodec = g_mvideo_avcodec_find_decoder(video_dec_ctx->codec_id);
+        if (g_mvideo_avcodec_open2(codec_context, videoCodec, 0) > 0) {
+            //用唯一的文件名绑定对应视频的对应pix_fmt值
+            setProperty(fi.filePath().toUtf8(), codec_context->pix_fmt);
+        }
+        g_mvideo_avcodec_free_context(&codec_context);
     }
     if (audioRet >= 0) {
         int audio_stream_index = -1;
@@ -440,7 +427,14 @@ void PlaylistModel::slotStateChanged()
     case PlayerEngine::Idle:
         if (!_userRequestingItem) {
             stop();
-            playNext(false);
+            //WINID方式渲染结束时，保证gpu渲染资源的正常释放与切换，延时5ms执行下部视频的播放
+            if(!CompositingManager::get().composited()) {
+                QTimer::singleShot(5, [=]() {
+                    playNext(false);
+                });
+            } else {
+                playNext(false);
+            }
         }
         break;
     }
@@ -474,26 +468,10 @@ PlaylistModel::PlaylistModel(PlayerEngine *e)
 #endif
 }
 
-QString PlaylistModel::libPath(const QString &strlib)
-{
-    QDir  dir;
-    QString path  = QLibraryInfo::location(QLibraryInfo::LibrariesPath);
-    dir.setPath(path);
-    QStringList list = dir.entryList(QStringList() << (strlib + "*"), QDir::NoDotAndDotDot | QDir::Files); //filter name with strlib
-    if (list.contains(strlib)) {
-        return strlib;
-    } else {
-        list.sort();
-    }
-    if (list.size()>0)
-        return list.last();
-    else
-        return QString();
-}
 
 void PlaylistModel::initThumb()
 {
-    QLibrary library(libPath("libffmpegthumbnailer.so"));
+    QLibrary library(SysUtils::libPath("libffmpegthumbnailer.so"));
     m_mvideo_thumbnailer = (mvideo_thumbnailer) library.resolve("video_thumbnailer_create");
     m_mvideo_thumbnailer_destroy = (mvideo_thumbnailer_destroy) library.resolve("video_thumbnailer_destroy");
     m_mvideo_thumbnailer_create_image_data = (mvideo_thumbnailer_create_image_data) library.resolve("video_thumbnailer_create_image_data");
@@ -517,9 +495,9 @@ void PlaylistModel::initThumb()
 
 void PlaylistModel::initFFmpeg()
 {
-    QLibrary avcodecLibrary(libPath("libavcodec.so"));
-    QLibrary avformatLibrary(libPath("libavformat.so"));
-    QLibrary avutilLibrary(libPath("libavutil.so"));
+    QLibrary avcodecLibrary(SysUtils::libPath("libavcodec.so"));
+    QLibrary avformatLibrary(SysUtils::libPath("libavformat.so"));
+    QLibrary avutilLibrary(SysUtils::libPath("libavutil.so"));
 
     g_mvideo_avformat_open_input = (mvideo_avformat_open_input) avformatLibrary.resolve("avformat_open_input");
     g_mvideo_avformat_find_stream_info = (mvideo_avformat_find_stream_info) avformatLibrary.resolve("avformat_find_stream_info");
@@ -531,6 +509,8 @@ void PlaylistModel::initFFmpeg()
     g_mvideo_av_get_media_type_string = (mvideo_av_get_media_type_string) avutilLibrary.resolve("av_get_media_type_string");
     g_mvideo_avcodec_alloc_context3 = (mvideo_avcodec_alloc_context3) avcodecLibrary.resolve("avcodec_alloc_context3");
     g_mvideo_avcodec_parameters_to_context = (mvideo_avcodec_parameters_to_context) avcodecLibrary.resolve("avcodec_parameters_to_context");
+    g_mvideo_avcodec_open2 = (mvideo_avcodec_open2)(avcodecLibrary.resolve("avcodec_open2"));
+    g_mvideo_avcodec_free_context = (mvideo_avcodec_free_context)(avcodecLibrary.resolve("avcodec_free_context"));
 
     m_initFFmpeg = true;
 }
@@ -678,10 +658,10 @@ QImage PlaylistModel::getMovieCover(const QUrl &url)
 }
 
 
-/*PlaylistModel::PlayMode PlaylistModel::playMode() const
+PlaylistModel::PlayMode PlaylistModel::playMode() const
 {
     return _playMode;
-}*/
+}
 
 void PlaylistModel::setPlayMode(PlaylistModel::PlayMode pm)
 {
@@ -1407,7 +1387,7 @@ bool PlaylistModel::getMusicPix(const QFileInfo &fi, QPixmap &rImg)
         return false;
     }
 
-    QLibrary library(libPath("libavformat.so"));
+    QLibrary library(SysUtils::libPath("libavformat.so"));
     mvideo_avformat_open_input g_mvideo_avformat_open_input_temp = (mvideo_avformat_open_input) library.resolve("avformat_open_input");
     mvideo_avformat_close_input g_mvideo_avformat_close_input = (mvideo_avformat_close_input) library.resolve("avformat_close_input");
     mvideo_avformat_find_stream_info g_mvideo_avformat_find_stream_info_temp = (mvideo_avformat_find_stream_info) library.resolve("avformat_find_stream_info");
