@@ -1,38 +1,14 @@
-/*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef _DMR_PLAYLIST_MODEL_H
 #define _DMR_PLAYLIST_MODEL_H
 
 #include <QtWidgets>
 //#include <QtConcurrent>
 #include <DApplicationHelper>
+#include <DGuiApplicationHelper>
 #include <libffmpegthumbnailer/videothumbnailerc.h>
 
 #include "utils.h"
@@ -44,6 +20,8 @@
 #define THUMBNAIL_SIZE 500
 #define SEEK_TIME "00:00:01"
 
+DGUI_USE_NAMESPACE
+
 typedef video_thumbnailer *(*mvideo_thumbnailer)();
 typedef void (*mvideo_thumbnailer_destroy)(video_thumbnailer *thumbnailer);
 /* create image_data structure */
@@ -288,7 +266,7 @@ private:
     bool getMusicPix(const QFileInfo &fi, QPixmap &rImg);
     struct MovieInfo parseFromFile(const QFileInfo &fi, bool *ok = nullptr);
     struct MovieInfo parseFromFileByQt(const QFileInfo &fi, bool *ok = nullptr);
-    QString libPath(const QString &strlib);
+
     // when app starts, and the first time to load playlist
     bool _firstLoad {true};
     int _count {0};
