@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     xiangxiaojun <xiangxiaoju@uniontech.com>
- *
- * Maintainer: liuzheng <liuzheng@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 /**
  *@file 这个文件是影片信息窗口相关的类
  */
@@ -125,7 +97,6 @@ protected:
     bool eventFilter(QObject *obj, QEvent *event)
     {
         switch (event->type()) {
-//        case QEvent::Enter:
         case QEvent::ToolTip: {
             QHelpEvent *he = static_cast<QHelpEvent *>(event);
             auto tip = obj->property("HintWidget").value<Tip *>();
@@ -187,40 +158,31 @@ protected:
         }
     }
 };
+
 /**
  * @brief MovieInfoDialog 构造函数
  */
 MovieInfoDialog::MovieInfoDialog(const struct PlayItemInfo &pif ,QWidget *parent)
-    : DAbstractDialog(parent)
+    : DDialog(parent)
 {
     initMember();
-   if(utils::check_wayland_env()){
-       setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
-   }else{
-       setWindowFlags(windowFlags() /*| Qt::WindowStaysOnTopHint*/);  //和其他应用保持统一取消置顶
-   }
+    if(utils::check_wayland_env()){
+        setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint);
+    }
+
     this->setObjectName(MOVIE_INFO_DIALOG);
     this->setAccessibleName(MOVIE_INFO_DIALOG);
     m_titleList.clear();
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setSpacing(0);
-    layout->setContentsMargins(0, 0, 0, 0);
-    setLayout(layout);
-
-    CloseButton *closeBt = new CloseButton(this);
-    closeBt->setObjectName(MOVIEINFO_CLOSE_BUTTON);
-    closeBt->setAccessibleName(MOVIEINFO_CLOSE_BUTTON);
-    closeBt->setFixedSize(50, 50);
-    connect(closeBt, &CloseButton::clicked, this, &MovieInfoDialog::close);
-    layout->addWidget(closeBt, 0, Qt::AlignTop | Qt::AlignRight);
+    DWidget *content = new DWidget();
+    addContent(content);
 
     const MovieInfo &strMovieInfo = pif.mi;
 
     QVBoxLayout *pMainLayout = new QVBoxLayout;
-    pMainLayout->setContentsMargins(10, 0, 0, 0);
+    pMainLayout->setContentsMargins(0, 0, 0, 0);
     pMainLayout->setSpacing(0);
-    layout->addLayout(pMainLayout);
+    content->setLayout(pMainLayout);
 
     PosterFrame *pPosterFrame = new PosterFrame(this);
     pPosterFrame->setWindowOpacity(1);
@@ -246,7 +208,6 @@ MovieInfoDialog::MovieInfoDialog(const struct PlayItemInfo &pif ,QWidget *parent
 
     m_pFileNameLbl->setMinimumWidth(260);
     DFontSizeManager::instance()->bind(m_pFileNameLbl, DFontSizeManager::T8);
-    m_pFileNameLbl->setForegroundRole(DPalette::BrightText);
     m_pFileNameLbl->setText(m_pFileNameLbl->fontMetrics().elidedText(QFileInfo(strMovieInfo.filePath).fileName(), Qt::ElideMiddle, 260));
     m_pFileNameLbl->setAlignment(Qt::AlignCenter);
     pMainLayout->addWidget(m_pFileNameLbl);
@@ -263,13 +224,13 @@ MovieInfoDialog::MovieInfoDialog(const struct PlayItemInfo &pif ,QWidget *parent
     palette.setBrush(QPalette::Background, Qt::NoBrush);
     m_pScrollArea->viewport()->setPalette(palette);
     m_pScrollArea->setFrameShape(QFrame::Shape::NoFrame);
-    pMainLayout->addWidget(m_pScrollArea);
     m_pScrollArea->setWidgetResizable(true);
+    pMainLayout->addWidget(m_pScrollArea);
 
     QWidget *scrollContentWidget = new QWidget(m_pScrollArea);
     scrollContentWidget->setObjectName(MOVIE_INFO_SCROLL_CONTENT);
     QVBoxLayout *scrollWidgetLayout = new QVBoxLayout;
-    scrollWidgetLayout->setContentsMargins(0, 0, 10, 10);
+    scrollWidgetLayout->setContentsMargins(0, 0, 0, 0);
     scrollWidgetLayout->setSpacing(10);
     scrollContentWidget->setLayout(scrollWidgetLayout);
     m_pScrollArea->setWidget(scrollContentWidget);
@@ -280,14 +241,16 @@ MovieInfoDialog::MovieInfoDialog(const struct PlayItemInfo &pif ,QWidget *parent
     ArrowLine *film = new ArrowLine;
     film->setObjectName(FILM_INFO_WIDGET);
     film->setTitle(tr("Film info"));
+    //去掉分割线
+    film->setSeparatorVisible(false);
+    film->setExpandedSeparatorVisible(false);
     InfoBottom *infoRect = new InfoBottom;
     scrollWidgetLayout->addWidget(film);
     scrollWidgetLayout->setAlignment(film, Qt::AlignHCenter);
     film->setContent(infoRect);
     film->setFixedWidth(280);
     infoRect->setFixedWidth(280);
-    infoRect->setMinimumHeight(132);
-    //infoRect->setFixedSize(280, 132);
+//    infoRect->setMinimumHeight(132);
     film->setExpand(true);
     m_expandGroup.append(film);
     QFormLayout *pFormLayout = new QFormLayout(infoRect);
@@ -296,23 +259,54 @@ MovieInfoDialog::MovieInfoDialog(const struct PlayItemInfo &pif ,QWidget *parent
     pFormLayout->setHorizontalSpacing(10);
     pFormLayout->setLabelAlignment(Qt::AlignLeft);
     pFormLayout->setFormAlignment(Qt::AlignCenter);
-    DEnhancedWidget *hanceedWidget = new DEnhancedWidget(film);
+    DEnhancedWidget *hanceedWidget = new DEnhancedWidget(film, this);
     connect(hanceedWidget, &DEnhancedWidget::heightChanged, this, &MovieInfoDialog::changedHeight);
 
+    QString strDuration = strMovieInfo.durationStr();
+    if(strDuration == "00:00:00") {
+        strDuration = "-";
+    }
+    QString strVCodecName = strMovieInfo.videoCodec();
+    if(strVCodecName == "none" || strVCodecName.isEmpty()) {
+        strVCodecName = "-";
+    }
+    QString strVCodecRate = "-";
+    if(strMovieInfo.vCodeRate > 0) {
+        strVCodecRate = strMovieInfo.vCodeRate > 1000 ? QString(tr("%1 kbps")).arg(strMovieInfo.vCodeRate / 1000)
+                  : QString(tr("%1 bps")).arg(strMovieInfo.vCodeRate);
+    }
+    QString strFps = strMovieInfo.fps > 0 ? QString(tr("%1 fps")).arg(strMovieInfo.fps) : "-";
+    QString strProportion = strMovieInfo.proportion > 0.0f ? QString(tr("%1")).arg(static_cast<double>(strMovieInfo.proportion)) : "-";
+    QString strResolution = strMovieInfo.width > 0 ? strMovieInfo.resolution : "-" ;
+
+    QString strACodecName = strMovieInfo.audioCodec();
+    if(strACodecName.isEmpty()) {
+        strACodecName = "-";
+    }
+    QString strACodecRate = "-";
+    if(strMovieInfo.aCodeRate > 1000) {
+        strACodecRate = strMovieInfo.aCodeRate > 1000 ? QString(tr("%1 kbps")).arg(strMovieInfo.aCodeRate / 1000)
+                 : QString(tr("%1 bps")).arg(strMovieInfo.aCodeRate);
+    }
+    QString strBits = strMovieInfo.aDigit > 0 ? QString(tr("%1 bits").arg(strMovieInfo.aDigit)) : "-";
+    QString strChannels = strMovieInfo.channels > 0 ? QString(tr("%1 channels")).arg(strMovieInfo.channels) : "-";
+    QString strSamp = strMovieInfo.sampling > 0 ? QString(tr("%1hz")).arg(strMovieInfo.sampling) : "-";
+
     addRow(tr("Type"), strMovieInfo.fileType, pFormLayout, tipLst);
     addRow(tr("Size"), strMovieInfo.sizeStr(), pFormLayout, tipLst);
-    addRow(tr("Duration"), strMovieInfo.durationStr(), pFormLayout, tipLst);
+    addRow(tr("Duration"), strDuration, pFormLayout, tipLst);
     DLabel *tmp = new DLabel;
     DFontSizeManager::instance()->bind(tmp, DFontSizeManager::T8);
     tmp->setText(strMovieInfo.filePath);
     QFontMetrics fontMetrics = tmp->fontMetrics();
-    auto w = fontMetrics.width(strMovieInfo.filePath);
     addRow(tr("Path"), strMovieInfo.filePath, pFormLayout, tipLst);
 
     //添加视频信息
     ArrowLine *video = new ArrowLine;
     video->setObjectName(CODEC_INFO_WIDGET);
     video->setTitle(tr("Codec info"));
+    video->setSeparatorVisible(false);
+    video->setExpandedSeparatorVisible(false);
     InfoBottom *videoRect = new InfoBottom;
     scrollWidgetLayout->addWidget(video);
     scrollWidgetLayout->setAlignment(video, Qt::AlignHCenter);
@@ -320,7 +314,6 @@ MovieInfoDialog::MovieInfoDialog(const struct PlayItemInfo &pif ,QWidget *parent
     video->setFixedSize(280, 136);
     videoRect->setFixedWidth(280);
     videoRect->setMinimumHeight(136);
-    //videoRect->setFixedSize(280, 136);
     video->setExpand(true);
     m_expandGroup.append(video);
     QFormLayout *pVideoFormLayout = new QFormLayout(videoRect);
@@ -329,19 +322,21 @@ MovieInfoDialog::MovieInfoDialog(const struct PlayItemInfo &pif ,QWidget *parent
     pVideoFormLayout->setHorizontalSpacing(10);
     pVideoFormLayout->setLabelAlignment(Qt::AlignLeft);
     pVideoFormLayout->setFormAlignment(Qt::AlignCenter);
-    DEnhancedWidget *videoWidget = new DEnhancedWidget(video);
+    DEnhancedWidget *videoWidget = new DEnhancedWidget(video, this);
     connect(videoWidget, &DEnhancedWidget::heightChanged, this, &MovieInfoDialog::changedHeight);
 
-    addRow(tr("Video CodecID"), strMovieInfo.videoCodec(), pVideoFormLayout, tipLst);
-    addRow(tr("Video CodeRate"), QString(tr("%1 kbps")).arg(strMovieInfo.vCodeRate), pVideoFormLayout, tipLst);
-    addRow(tr("FPS"), QString(tr("%1 fps")).arg(strMovieInfo.fps), pVideoFormLayout, tipLst);
-    addRow(tr("Proportion"), QString(tr("%1")).arg(static_cast<double>(strMovieInfo.proportion)), pVideoFormLayout, tipLst);
-    addRow(tr("Resolution"), strMovieInfo.resolution, pVideoFormLayout, tipLst);
+    addRow(tr("Video CodecID"), strVCodecName, pVideoFormLayout, tipLst);
+    addRow(tr("Video CodeRate"), strVCodecRate, pVideoFormLayout, tipLst);
+    addRow(tr("FPS"), strFps, pVideoFormLayout, tipLst);
+    addRow(tr("Proportion"), strProportion, pVideoFormLayout, tipLst);
+    addRow(tr("Resolution"), strResolution, pVideoFormLayout, tipLst);
 
     //添加音频信息
     ArrowLine *audio = new ArrowLine;
     audio->setObjectName(AUDIO_INFO_WIDGET);
     audio->setTitle(tr("Audio info"));
+    audio->setSeparatorVisible(false);
+    audio->setExpandedSeparatorVisible(false);
     InfoBottom *audioRect = new InfoBottom;
     scrollWidgetLayout->addWidget(audio);
     scrollWidgetLayout->setAlignment(audio, Qt::AlignHCenter);
@@ -349,23 +344,22 @@ MovieInfoDialog::MovieInfoDialog(const struct PlayItemInfo &pif ,QWidget *parent
     audio->setFixedWidth(280);
     audioRect->setFixedWidth(280);
     audioRect->setMinimumHeight(136);
-    //audioRect->setFixedSize(280, 136);
     audio->setExpand(true);
     m_expandGroup.append(audio);
-    auto *audioForm = new QFormLayout(audioRect);
+    QFormLayout *audioForm = new QFormLayout(audioRect);
     audioForm->setContentsMargins(10, 5, 20, 16);
     audioForm->setVerticalSpacing(6);
     audioForm->setHorizontalSpacing(10);
     audioForm->setLabelAlignment(Qt::AlignLeft);
     audioForm->setFormAlignment(Qt::AlignCenter);
-    DEnhancedWidget *audioWidget = new DEnhancedWidget(audio);
+    DEnhancedWidget *audioWidget = new DEnhancedWidget(audio, this);
     connect(audioWidget, &DEnhancedWidget::heightChanged, this, &MovieInfoDialog::changedHeight);
 
-    addRow(tr("Audio CodecID"), strMovieInfo.audioCodec(), audioForm, tipLst);
-    addRow(tr("Audio CodeRate"), QString(tr("%1 kbps")).arg(strMovieInfo.aCodeRate), audioForm, tipLst);
-    addRow(tr("Audio digit"), QString(tr("%1 bits").arg(strMovieInfo.aDigit)), audioForm, tipLst);
-    addRow(tr("Channels"), QString(tr("%1 channels")).arg(strMovieInfo.channels), audioForm, tipLst);
-    addRow(tr("Sampling"), QString(tr("%1hz")).arg(strMovieInfo.sampling), audioForm, tipLst);
+    addRow(tr("Audio CodecID"), strACodecName, audioForm, tipLst);
+    addRow(tr("Audio CodeRate"), strACodecRate, audioForm, tipLst);
+    addRow(tr("Audio digit"), strBits, audioForm, tipLst);
+    addRow(tr("Channels"), strChannels, audioForm, tipLst);
+    addRow(tr("Sampling"), strSamp, audioForm, tipLst);
 
     setFixedSize(300, 642);
 
@@ -397,7 +391,6 @@ MovieInfoDialog::MovieInfoDialog(const struct PlayItemInfo &pif ,QWidget *parent
         t->setProperty("for", QVariant::fromValue<QWidget *>(pFilePathLbl));
         pFilePathLbl->setProperty("HintWidget", QVariant::fromValue<QWidget *>(t));
         pFilePathLbl->installEventFilter(th);
-//        filePathLbl->hide();
     }
 
     delete tmp;
@@ -417,9 +410,21 @@ MovieInfoDialog::MovieInfoDialog(const struct PlayItemInfo &pif ,QWidget *parent
 void MovieInfoDialog::paintEvent(QPaintEvent *ev)
 {
     QPainter painter(this);
-    painter.fillRect(this->rect(), QColor(0, 0, 0, static_cast<int>(255 * 0.8)));
+    if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
+        painter.fillRect(this->rect(), QColor(255, 255, 255, static_cast<int>(255 * 0.8)));
+    } else {
+        painter.fillRect(this->rect(), QColor(0, 0, 0, static_cast<int>(255 * 0.8)));
+    }
+
     QDialog::paintEvent(ev);
 }
+
+void MovieInfoDialog::showEvent(QShowEvent *pEvent)
+{
+    moveToCenter();
+
+    return QDialog::showEvent(pEvent);
+}
 /**
  * @brief onFontChanged 字体变化槽函数（跟随系统变化）
  * @param font 变化后的字体
@@ -441,34 +446,20 @@ void MovieInfoDialog::onFontChanged(const QFont &font)
  */
 void MovieInfoDialog::changedHeight(const int height)
 {
-    if (m_nLastHeight == -1) {
-        m_nLastHeight = height;
-    } else {
-        //xpf修改此过程
-        int h = 10;
-        if (m_expandGroup.at(0)->expand()) {
-            h = h + 164;
-        } else {
-            h = h + 32;
-        }
-        if (m_expandGroup.at(1)->expand()) {
-            h = h + 168 + 10;
-        } else {
-            h = h + 32 + 10;
-        }
-        if (m_expandGroup.at(2)->expand()) {
-            h = h + 168 + 10;
-        } else {
-            h = h + 32 + 10;
-        }
-        h += 260;
-        if (h > 642) {
-            this->setFixedHeight(642);
-        } else {
-            setFixedHeight(h);
-        }
-        m_nLastHeight = -1;
+    QRect rc = geometry();
+    int expandsHeight = 30;
+    QList<DDrawer *>::const_iterator expand = m_expandGroup.cbegin();
+
+    while (expand != m_expandGroup.cend()) {
+        expandsHeight += (*expand)->height();
+        ++expand;
     }
+
+    expandsHeight += contentsMargins().top() + contentsMargins().bottom();
+    rc.setHeight(expandsHeight + 265);
+
+    setGeometry(rc);
+    this->setFixedHeight(qMin(615, expandsHeight + 265));
 }
 /**
  * @brief slotThemeTypeChanged
@@ -490,14 +481,19 @@ void MovieInfoDialog::addRow(QString sTitle, QString sField, QFormLayout *pForm,
     auto f = new DLabel(sTitle, this);
     f->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     f->setMinimumSize(60, 20);
-    QFont font = f->font();
-    font.setPixelSize(12);
-    font.setWeight(QFont::Weight::Normal);
-    font.setFamily("SourceHanSansSC");
+    DFontSizeManager::instance()->bind(f, DFontSizeManager::T8);
+    DPalette pa1 = DApplicationHelper::instance()->palette(f);
+    pa1.setBrush(DPalette::Text, pa1.color(DPalette::TextTitle));
+    f->setPalette(pa1);
+
     auto t = new DLabel(sField, this);
     t->setAlignment(Qt::AlignLeft | Qt::AlignTop);
     t->setMinimumHeight(20);
     t->setWordWrap(true);
+    DFontSizeManager::instance()->bind(t, DFontSizeManager::T8);
+    DPalette pa2 = DApplicationHelper::instance()->palette(t);
+    pa2.setBrush(DPalette::Text, pa2.color(DPalette::TextTitle));
+    t->setPalette(pa2);
     pForm->addRow(f, t);
     tipList.append(t);
     m_titleList.append(f);
