@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     zhuyuliang <zhuyuliang@uniontech.com>
- *
- * Maintainer: liuzheng <liuzheng@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "platform_playlist_widget.h"
 #include "playlist_model.h"
 #include "compositing_manager.h"
@@ -223,6 +195,41 @@ public:
         m_opacityEffect_1 = new QGraphicsOpacityEffect;
         _index->setGraphicsEffect(m_opacityEffect_1);
         setState(ItemState::Normal);
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        setFixedHeight(24);
+        _closeBtn->setIconSize(QSize(18, 18));
+        _closeBtn->setFixedSize(17, 17);
+        _name->setFixedHeight(24);
+        if (_thumb)
+            _thumb->setFixedSize(28, 16);
+        else
+            m_pSvgWidget->setFixedSize(28, 16);
+    }
+
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [=](DGuiApplicationHelper::SizeMode sizeMode) {
+        if (sizeMode == DGuiApplicationHelper::NormalMode) {
+            setFixedHeight(36);
+            _closeBtn->setIconSize(QSize(28, 28));
+            _closeBtn->setFixedSize(25, 25);
+            _name->setFixedHeight(36);
+            if (_thumb)
+                _thumb->setFixedSize(42, 24);
+            else
+                m_pSvgWidget->setFixedSize(42, 24);
+        } else {
+            setFixedHeight(24);
+            _closeBtn->setIconSize(QSize(18, 18));
+            _closeBtn->setFixedSize(17, 17);
+            _name->setFixedHeight(24);
+            if (_thumb)
+                _thumb->setFixedSize(28, 16);
+            else
+                m_pSvgWidget->setFixedSize(28, 16);
+        }
+        updateClosePosition();
+    });
+#endif
     }
     
     ~Platform_PlayItemWidget() override
@@ -317,6 +324,9 @@ public:
         }
         if (!_pif.url.isLocalFile() || _pif.info.exists()) {
             emit doubleClicked();
+        }else{
+            //fixed:影院循环播放10个smb上的视频一段时间后，点击播放按钮或点击列表中的视频没反应
+            emit _playlist->engine()->sigInvalidFile(QFileInfo(_pif.url.toLocalFile()).fileName());
         }
     }
 
@@ -434,10 +444,6 @@ protected:
     }
     bool event(QEvent *ee) override
     {
-        if (ee->type() == QEvent::Resize) {
-            _name->setFixedHeight(36);
-        }
-
         if (ee->type() == QEvent::Move) {
         }
 
@@ -448,7 +454,6 @@ protected:
         _name->setText(utils::ElideText(_pif.mi.title, {width() - 242, 36}, QTextOption::NoWrap,
                                         _name->font(), Qt::ElideRight, 18, width() - 242));
         _name->setCursor(Qt::ArrowCursor);
-        _name->setFixedHeight(36);
     }
     void showEvent(QShowEvent *se) override
     {
@@ -800,6 +805,22 @@ Platform_PlaylistWidget::Platform_PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
 
     }
 
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [=](DGuiApplicationHelper::SizeMode sizeMode) {
+        if (sizeMode == DGuiApplicationHelper::NormalMode) {
+            for (int i = 0; i < _playlist->count(); i++) {
+                QListWidgetItem *item = _playlist->item(i);
+                item->setSizeHint(QSize(_playlist->itemWidget(item)->width(), 36));
+            }
+        } else {
+            for (int i = 0; i < _playlist->count(); i++) {
+                QListWidgetItem *item = _playlist->item(i);
+                item->setSizeHint(QSize(_playlist->itemWidget(item)->width(), 24));
+            }
+        }
+    });
+#endif
+
     connect(&_engine->playlist(), &PlaylistModel::emptied, this, &Platform_PlaylistWidget::clear);
     connect(&_engine->playlist(), &PlaylistModel::itemsAppended, this, &Platform_PlaylistWidget::appendItems);
     connect(&_engine->playlist(), &PlaylistModel::itemRemoved, this, &Platform_PlaylistWidget::removeItem);
@@ -817,6 +838,7 @@ Platform_PlaylistWidget::Platform_PlaylistWidget(QWidget *mw, PlayerEngine *mpv)
         });
     });
     connect(ActionFactory::get().playlistContextMenu(), &DMenu::aboutToHide, [ = ]() {
+        m_pClearButton->update();
         if (_mouseItem) {
             (static_cast<Platform_PlayItemWidget *>(_mouseItem))->setHovered(false);
         }
@@ -1314,7 +1336,10 @@ void Platform_PlaylistWidget::togglePopup(bool isShortcut)
     if (paOpen != nullptr || paClose != nullptr) {
         return ;
     }
-
+/**
+ * 此处在动画执行前设定好Platform_PlaylistWidget起始位置和终止位置
+ * 基于 Platform_MainWindow::updateProxyGeometry 所设置的初始状态 以及 是否是紧凑模式 定位Platform_PlaylistWidget的起始位置和终止位置。
+*/
     QRect main_rect = _mw->rect();
 #ifdef USE_DXCB
     QRect view_rect = main_rect;
@@ -1322,9 +1347,16 @@ void Platform_PlaylistWidget::togglePopup(bool isShortcut)
     QRect view_rect = main_rect.marginsRemoved(QMargins(1, 1, 1, 1));
 #endif
 
+    int toolbox_height = TOOLBOX_HEIGHT;
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        toolbox_height = TOOLBOX_DSIZEMODE_HEIGHT;
+    }
+#endif
+
     QRect fixed;
     // y坐标下移5个像素点,避免播放列表上部超出toolbox范围
-    fixed.setRect(10, (view_rect.height() - (TOOLBOX_SPACE_HEIGHT + TOOLBOX_HEIGHT + 10) + 5),
+    fixed.setRect(10, (view_rect.height() - (TOOLBOX_SPACE_HEIGHT + toolbox_height + 10) + 5),
                   view_rect.width() - 20, TOOLBOX_SPACE_HEIGHT + 10);
 
     QRect shrunk = fixed;
