@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     fengli <fengli@uniontech.com>
- *
- * Maintainer: xiepengfei <xiepengfei@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "config.h"
 
 #include "platform_toolbox_proxy.h"
@@ -45,6 +17,7 @@
 #include "tip.h"
 #include "utils.h"
 #include "filefilter.h"
+#include "sysutils.h"
 
 //#include <QtWidgets>
 #include <DImageButton>
@@ -57,6 +30,7 @@
 #include <QDBusInterface>
 #include <DToolButton>
 #include <dthememanager.h>
+#include <DWindowManagerHelper>
 #include <iostream>
 #include "../accessibility/ac-deepin-movie-define.h"
 static const int LEFT_MARGIN = 10;
@@ -96,7 +70,24 @@ public:
      * @brief TooltipHandler 构造函数
      * @param parent 父窗口
      */
-    explicit Platform_TooltipHandler(QObject *parent): QObject(parent) {}
+    explicit Platform_TooltipHandler(QObject *parent): QObject(parent) {
+        connect(&m_showTime, &QTimer::timeout, [=]{
+            //QHelpEvent *he = static_cast<QHelpEvent *>(event);
+            if (m_object != nullptr) {
+                auto tip = m_object->property("HintWidget").value<Tip *>();
+                auto btn = tip->property("for").value<QWidget *>();
+                tip->setText(btn->toolTip());
+                tip->show();
+                tip->raise();
+                tip->adjustSize();
+
+                QPoint pos = btn->parentWidget()->mapToGlobal(btn->pos());
+                pos.rx() = pos.x() + (btn->width() - tip->width()) / 2;
+                pos.ry() = pos.y() - 40;
+                tip->move(pos);
+            }
+        });
+    }
 
 protected:
     /**
@@ -110,22 +101,15 @@ protected:
         switch (event->type()) {
         case QEvent::ToolTip:
         case QEvent::Enter: {
-            //QHelpEvent *he = static_cast<QHelpEvent *>(event);
-            auto tip = obj->property("HintWidget").value<Tip *>();
-            auto btn = tip->property("for").value<QWidget *>();
-            tip->setText(btn->toolTip());
-            tip->show();
-            tip->raise();
-            tip->adjustSize();
-
-            QPoint pos = btn->parentWidget()->mapToGlobal(btn->pos());
-            pos.rx() = pos.x() + (btn->width() - tip->width()) / 2;
-            pos.ry() = pos.y() - 40;
-            tip->move(pos);
+            m_object = obj;
+            if (!m_showTime.isActive())
+                m_showTime.start(1000);
             return true;
         }
 
         case QEvent::Leave: {
+            m_object = nullptr;
+            m_showTime.stop();
             auto parent = obj->property("HintWidget").value<Tip *>();
             parent->hide();
             event->ignore();
@@ -142,6 +126,10 @@ protected:
         // standard event processing
         return QObject::eventFilter(obj, event);
     }
+
+private:
+    QTimer m_showTime;
+    QObject *m_object {nullptr};
 };
 /**
  * @brief The SliderTime class 进度条事件显示类
@@ -306,7 +294,25 @@ public:
         m_pViewProgBarLayout_black = new QHBoxLayout(m_pFront);
         m_pViewProgBarLayout_black->setContentsMargins(0, 5, 0, 5);
         m_pFront->setLayout(m_pViewProgBarLayout_black);
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        setFixedHeight(46);
+        m_pBack->setFixedHeight(40);
+        m_pFront->setFixedHeight(40);
+    }
 
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [=](DGuiApplicationHelper::SizeMode sizeMode) {
+        if (sizeMode == DGuiApplicationHelper::NormalMode) {
+            setFixedHeight(70);
+            m_pBack->setFixedHeight(60);
+            m_pFront->setFixedHeight(60);
+        } else {
+            setFixedHeight(46);
+            m_pBack->setFixedHeight(40);
+            m_pFront->setFixedHeight(40);
+        }
+    });
+#endif
     }
 //    virtual ~ViewProgBar();
     void setIsBlockSignals(bool isBlockSignals)
@@ -366,19 +372,26 @@ public:
         /*这段代码将胶片添加到两个label中，一个label置灰，一个彩色，通过光标调整两个label的位置
          *以实现通过光标来显示播放过的位置
          */
-        const int nPixWidget = 40/*m_pProgBar->width() / 100*/;
+        int nPixWidget = 40/*m_pProgBar->width() / 100*/;
+        int npixHeight = 50;
+#ifdef DTKWIDGET_CLASS_DSizeMode
+            if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::SizeMode::CompactMode) {
+                nPixWidget = nPixWidget * 0.66;
+                npixHeight = npixHeight * 0.66;
+            }
+#endif
         m_nViewLength = (nPixWidget + 1) * pmList.count() - 1;
         m_nStartPoint = (m_pProgBar->width() - m_nViewLength) / 2; //开始位置
         for (int i = 0; i < pmList.count(); i++) {
             Platform_ImageItem *label = new Platform_ImageItem(pmList.at(i), false, m_pBack);
             label->setMouseTracking(true);
             label->move(i * (nPixWidget + 1) + m_nStartPoint, 5);
-            label->setFixedSize(nPixWidget, 50);
+            label->setFixedSize(nPixWidget, npixHeight);
 
             Platform_ImageItem *label_black = new Platform_ImageItem(pmBlackList.at(i), true, m_pFront);
             label_black->setMouseTracking(true);
             label_black->move(i * (nPixWidget + 1) + m_nStartPoint, 5);
-            label_black->setFixedSize(nPixWidget, 50);
+            label_black->setFixedSize(nPixWidget, npixHeight);
         }
         update();
     }
@@ -602,26 +615,15 @@ public:
         setWindowFlags(Qt::ToolTip | Qt::FramelessWindowHint);
         setAttribute(Qt::WA_TranslucentBackground);
         setObjectName("ThumbnailPreview");
-
-        m_pWMDBus = new QDBusInterface("com.deepin.WMSwitcher", "/com/deepin/WMSwitcher", "com.deepin.WMSwitcher", QDBusConnection::sessionBus());
-        QDBusReply<QString> reply = m_pWMDBus->call("CurrentWM");
-        m_bIsWM = reply.value().contains("deepin wm");
-        connect(m_pWMDBus, SIGNAL(WMChanged(QString)), this, SLOT(slotWMChanged(QString)));
-
-        auto *l = new QVBoxLayout;
-        l->setContentsMargins(0, 0, 0, 0);
-
-        _thumb = new DFrame(this);
+        resize(0, 0);
+       
+        connect(DWindowManagerHelper::instance(), &DWindowManagerHelper::hasBlurWindowChanged, this, &Platform_ThumbnailPreview::slotWMChanged);
+        m_bIsWM = DWindowManagerHelper::instance()->hasBlurWindow();
         if (m_bIsWM) {
-            DStyle::setFrameRadius(_thumb, 8);
+            DStyle::setFrameRadius(this, 8);
         } else {
-            DStyle::setFrameRadius(_thumb, 0);
+            DStyle::setFrameRadius(this, 0);
         }
-
-        //_thumb->setFixedSize(ThumbnailWorker::thumbSize());
-        l->addWidget(_thumb/*,Qt::AlignTop*/);
-        setLayout(l);
-//        winId(); // force backed window to be created
         m_shadow_effect = new QGraphicsDropShadowEffect(this);
     }
 
@@ -655,29 +657,25 @@ public:
         QImage image;
         QPalette palette;
         image = rounded.toImage();
-        palette.setBrush(_thumb->backgroundRole(),
-                         QBrush(image.scaled(// 缩放背景图.
-                                    QSize(_thumb->width(), _thumb->height()),
-                                    Qt::IgnoreAspectRatio,
-                                    Qt::SmoothTransformation)));
-        _thumb->setPalette(palette);
+        m_thumbImg = image;
+        update();
     }
 
     void updateWithPreview(const QPoint &pos)
     {
         move(pos.x() - this->width() / 2, pos.y() - this->height() + 10);
-
-        show();
+        if(geometry().isValid()) {
+            show();
+        }
     }
 public slots:
-    void slotWMChanged(QString msg)
+    void slotWMChanged()
     {
-        if (msg.contains("deepin metacity")) {
-            m_bIsWM = false;
-            DStyle::setFrameRadius(_thumb, 0);
+        m_bIsWM = DWindowManagerHelper::instance()->hasBlurWindow();
+        if (m_bIsWM) {
+            DStyle::setFrameRadius(this, 8);
         } else {
-            m_bIsWM = true;
-            DStyle::setFrameRadius(_thumb, 8);
+            DStyle::setFrameRadius(this, 0);
         }
     }
 
@@ -690,14 +688,20 @@ protected:
         m_shadow_effect->setColor(Qt::gray);
         m_shadow_effect->setBlurRadius(8);
         setGraphicsEffect(m_shadow_effect);
+        QPainter painter(this);
+        QPainterPath path;
+        QRect rt = rect().marginsRemoved(QMargins(1, 1, 1, 1));
         if (!m_bIsWM)
         {
-            QPainter painter(this);
-            QPainterPath path;
             path.addRect(rect());
             painter.fillPath(path, QColor(230, 230, 230));
+        } else {
+            path.addRoundRect(rt, 20, 20);
+            painter.setRenderHints(QPainter::Antialiasing, true);
         }
-
+        painter.setClipPath(path);
+        if(!m_thumbImg.isNull())
+            painter.drawImage(rt, m_thumbImg, QRect(0, 0, m_thumbImg.width(), m_thumbImg.height()));
         QWidget::paintEvent(e);
     }
     void leaveEvent(QEvent *e) override
@@ -717,42 +721,25 @@ private:
         pixmap.setDevicePixelRatio(dpr);
         pixmap = pixmap.scaled(size * dpr, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation);
         pixmap.setDevicePixelRatio(dpr);
-        _thumb->setFixedSize(size);
         int offect = 2;
         if (!m_bIsWM) {
             offect = 0;
         }
-        this->setFixedWidth(_thumb->width() + offect);
-        this->setFixedHeight(_thumb->height() + offect);
+        this->setFixedWidth(size.width() + offect);
+        this->setFixedHeight(size.height() + offect);
     }
 
 private:
-    DFrame *_thumb {nullptr};
+    QImage m_thumbImg;
     int m_thumbnailFixed = 106;
     QGraphicsDropShadowEffect *m_shadow_effect{nullptr};
-    QDBusInterface *m_pWMDBus{nullptr};
     bool m_bIsWM{false};
 };
 
-static QString libPath(const QString &strlib)
-{
-    QDir  dir;
-    QString path  = QLibraryInfo::location(QLibraryInfo::LibrariesPath);
-    dir.setPath(path);
-    QStringList list = dir.entryList(QStringList() << (strlib + "*"), QDir::NoDotAndDotDot | QDir::Files); //filter name with strlib
-    if (list.contains(strlib)) {
-        return strlib;
-    } else {
-        list.sort();
-    }
-
-    Q_ASSERT(list.size() > 0);
-    return list.last();
-}
 
 void Platform_viewProgBarLoad::initThumb()
 {
-    QLibrary library(libPath("libffmpegthumbnailer.so"));
+    QLibrary library(SysUtils::libPath("libffmpegthumbnailer.so"));
     m_mvideo_thumbnailer = (mvideo_thumbnailer) library.resolve("video_thumbnailer_create");
     m_mvideo_thumbnailer_destroy = (mvideo_thumbnailer_destroy) library.resolve("video_thumbnailer_destroy");
     m_mvideo_thumbnailer_create_image_data = (mvideo_thumbnailer_create_image_data) library.resolve("video_thumbnailer_create_image_data");
@@ -781,6 +768,11 @@ void Platform_viewProgBarLoad::loadViewProgBar(QSize size)
 {
     int pixWidget =  40;
     int num = int(m_pProgBar->width() / (40 + 1)); //number of thumbnails
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        num = int(m_pProgBar->width() / (26 + 1));
+    }
+#endif
     int tmp = (num == 0) ? 0: (m_pEngine->duration() * 1000) / num;
 
     QList<QPixmap> pmList;
@@ -863,13 +855,15 @@ Platform_ToolboxProxy::Platform_ToolboxProxy(QWidget *mainWindow, PlayerEngine *
     m_pPreviewer = new Platform_ThumbnailPreview;
     m_pPreviewTime = new Platform_SliderTime;
     m_pPreviewTime->hide();
+    m_mircastWidget = new MircastWidget(mainWindow, proxy);
+    m_mircastWidget->hide();
     setup();
     slotThemeTypeChanged();
 
     connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged,
             this, &Platform_ToolboxProxy::updatePlayState);
-    connect(DApplicationHelper::instance(), &DApplicationHelper::themeTypeChanged,
-            this, &Platform_ToolboxProxy::updateplaylisticon);
+    connect(m_mircastWidget, &MircastWidget::updatePlayStatus, this, &Platform_ToolboxProxy::updatePlayState);
+    connect(m_mircastWidget, &MircastWidget::updateTime, this, &Platform_ToolboxProxy::updateMircastTime, Qt::QueuedConnection);
 }
 void Platform_ToolboxProxy::finishLoadSlot(QSize size)
 {
@@ -903,15 +897,6 @@ void Platform_ToolboxProxy::setthumbnailmode()
     updateMovieProgress();
 }
 
-void Platform_ToolboxProxy::updateplaylisticon()
-{
-    if (m_pListBtn->isChecked() && DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
-        m_pListBtn->setIcon(QIcon(":/icons/deepin/builtin/light/checked/episodes_checked.svg"));
-    } else {
-        m_pListBtn->setIcon(QIcon::fromTheme("dcc_episodes"));
-    }
-}
-
 void Platform_ToolboxProxy::setup()
 {
     QStackedLayout *stacked = new QStackedLayout(this);
@@ -1142,6 +1127,23 @@ void Platform_ToolboxProxy::setup()
     _right->addWidget(m_pVolBtn);
     _right->addSpacing(10);
 
+    m_pMircastBtn = new ToolButton(m_pBotToolWgt);
+    m_pMircastBtn->setIcon(QIcon::fromTheme("dcc_mircast", QIcon(":/resources/icons/mircast/mircast.svg")));
+    m_pMircastBtn->setIconSize(QSize(24, 24));
+    m_pMircastBtn->installEventFilter(this);
+    m_pMircastBtn->setCheckable(true);
+    m_pMircastBtn->setFixedSize(50, 50);
+    m_pMircastBtn->setFocusPolicy(Qt::TabFocus);
+    m_pMircastBtn->initToolTip();
+    m_pMircastBtn->setObjectName(MIRVAST_BUTTON);
+    m_pMircastBtn->setAccessibleName(MIRVAST_BUTTON);
+    connect(m_pMircastBtn, SIGNAL(clicked()), signalMapper, SLOT(map()));
+    signalMapper->setMapping(m_pMircastBtn, "mircast");
+    connect(m_mircastWidget, &MircastWidget::mircastState, this, &Platform_ToolboxProxy::slotUpdateMircast);
+
+    _right->addWidget(m_pMircastBtn);
+    _right->addSpacing(10);
+
     m_pListBtn = new ToolButton(m_pBotToolWgt);
     m_pListBtn->setIcon(QIcon::fromTheme("dcc_episodes"));
     m_pListBtn->setIconSize(QSize(36, 36));
@@ -1164,15 +1166,15 @@ void Platform_ToolboxProxy::setup()
     //lmh0910wayland下用这一套tooltip
     Platform_TooltipHandler *th = new Platform_TooltipHandler(this);
     QWidget *btns[] = {
-        m_pPlayBtn, m_pPrevBtn, m_pNextBtn, m_pFullScreenBtn, m_pListBtn
+        m_pPlayBtn, m_pPrevBtn, m_pNextBtn, m_pFullScreenBtn, m_pMircastBtn, m_pListBtn
     };
     QString hints[] = {
         tr("Play/Pause"), tr("Previous"), tr("Next"),
-        tr("Fullscreen"), tr("Playlist")
+        tr("Fullscreen"), tr("Miracast"), tr("Playlist")
     };
     QString attrs[] = {
-        tr("play"), tr("prev"), tr("next"),
-        tr("fs"), tr("list")
+        "play", "prev", "next",
+        "fs", "mir", "list"
     };
 
     for (unsigned int i = 0; i < sizeof(btns) / sizeof(btns[0]); i++) {
@@ -1204,6 +1206,82 @@ void Platform_ToolboxProxy::setup()
     connect(&m_pEngine->playlist(), &PlaylistModel::countChanged, this, &Platform_ToolboxProxy::updateButtonStates);
     connect(m_pMainWindow, &Platform_MainWindow::initChanged, this, &Platform_ToolboxProxy::updateButtonStates);
 
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        m_pBotToolWgt->setFixedHeight((TOOLBOX_HEIGHT - 12)*0.66);
+        progBarspec->setContentsMargins(0, 0, 0, 0);
+        m_pBotSpec->setFixedHeight(20);
+        m_pPalyBox->setFixedWidth(79);
+        m_pPrevBtn->setIconSize(QSize(24, 24));
+        m_pPrevBtn->setFixedSize(26, 33);
+        m_pPlayBtn->setIconSize(QSize(24, 24));
+        m_pPlayBtn->setFixedSize(26, 33);
+        m_pNextBtn->setIconSize(QSize(24, 24));
+        m_pNextBtn->setFixedSize(26, 33);
+        m_pFullScreenBtn->setIconSize(QSize(24, 24));
+        m_pFullScreenBtn->setFixedSize(33, 33);
+        m_pVolBtn->setFixedSize(33, 33);
+        m_pMircastBtn->setIconSize(QSize(16, 16));
+        m_pMircastBtn->setFixedSize(33, 33);
+        m_pListBtn->setIconSize(QSize(24, 24));
+        m_pListBtn->setFixedSize(33, 33);
+    }
+
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, this, [=](DGuiApplicationHelper::SizeMode sizeMode) {
+        if (sizeMode == DGuiApplicationHelper::NormalMode) {
+            m_pBotToolWgt->setFixedHeight(TOOLBOX_HEIGHT - 12);
+            m_pBotSpec->setFixedHeight(30);
+            m_pPalyBox->setFixedWidth(120);
+            m_pPrevBtn->setIconSize(QSize(36, 36));
+            m_pPrevBtn->setFixedSize(40, 50);
+            m_pPlayBtn->setIconSize(QSize(36, 36));
+            m_pPlayBtn->setFixedSize(40, 50);
+            m_pNextBtn->setIconSize(QSize(36, 36));
+            m_pNextBtn->setFixedSize(40, 50);
+            m_pFullScreenBtn->setIconSize(QSize(36, 36));
+            m_pFullScreenBtn->setFixedSize(50, 50);
+            m_pVolBtn->setFixedSize(50, 50);
+            m_pMircastBtn->setIconSize(QSize(24, 24));
+            m_pMircastBtn->setFixedSize(50, 50);
+            m_pListBtn->setIconSize(QSize(36, 36));
+            m_pListBtn->setFixedSize(50, 50);
+        } else {
+            m_pBotToolWgt->setFixedHeight((TOOLBOX_HEIGHT - 12)*0.66);
+            m_pBotSpec->setFixedHeight(20);
+            m_pPalyBox->setFixedWidth(79);
+            m_pPrevBtn->setIconSize(QSize(24, 24));
+            m_pPrevBtn->setFixedSize(26, 33);
+            m_pPlayBtn->setIconSize(QSize(24, 24));
+            m_pPlayBtn->setFixedSize(26, 33);
+            m_pNextBtn->setIconSize(QSize(24, 24));
+            m_pNextBtn->setFixedSize(26, 33);
+            m_pFullScreenBtn->setIconSize(QSize(24, 24));
+            m_pFullScreenBtn->setFixedSize(33, 33);
+            m_pVolBtn->setFixedSize(33, 33);
+            m_pMircastBtn->setIconSize(QSize(16, 16));
+            m_pMircastBtn->setFixedSize(33, 33);
+            m_pListBtn->setIconSize(QSize(24, 24));
+            m_pListBtn->setFixedSize(33, 33);
+        }
+        if (m_pEngine->state() != PlayerEngine::CoreState::Idle) {
+            if (m_bThumbnailmode) {  //如果进度条为胶片模式，重新加载缩略图并显示
+                if(CompositingManager::get().platform() == Platform::X86) {
+                    updateThumbnail();
+                }
+                updateMovieProgress();
+            }
+            m_pProgBar_Widget->setCurrentIndex(1);
+        }
+    });
+    connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::sizeModeChanged, progBarspec, [=](DGuiApplicationHelper::SizeMode sizeMode) {
+        if (sizeMode == DGuiApplicationHelper::NormalMode) {
+            progBarspec->setContentsMargins(0, 5, 0, 0);
+        } else {
+            progBarspec->setContentsMargins(0, 0, 0, 0);
+        }
+    });
+#endif
+
     updatePlayState();
     updateFullState();
     updateButtonStates();
@@ -1216,9 +1294,6 @@ void Platform_ToolboxProxy::updateThumbnail()
 {
     disconnect(m_pWorker, SIGNAL(sigFinishiLoad(QSize)), this, SLOT(finishLoadSlot(QSize)));
 
-    //如果打开的是音乐
-    QString suffix = m_pEngine->playlist().currentInfo().info.suffix();
-
     if (m_pEngine->currFileIsAudio()) {
         return;
     }
@@ -1261,6 +1336,7 @@ void Platform_ToolboxProxy::initMember()
     m_pProgBar = nullptr;
     m_pPreviewer = nullptr;
     m_pPreviewTime = nullptr;
+    m_mircastWidget = nullptr;
 
     m_pPlayBtn = nullptr;
     m_pPrevBtn = nullptr;
@@ -1307,7 +1383,7 @@ void Platform_ToolboxProxy::closeAnyPopup()
 
     if (m_pVolSlider->isVisible()) {
         m_pVolSlider->stopTimer();
-        m_pVolSlider->popup();
+        m_pVolSlider->hide();
     }
 }
 /**
@@ -1372,7 +1448,6 @@ void Platform_ToolboxProxy::updateHoverPreview(const QUrl &url, int secs)
     if (!pm.isNull()) {
         QPoint point { showPoint.x(), showPoint.y() };
         m_pPreviewer->updateWithPreview(pm, secs, m_pEngine->videoRotation());
-        m_pPreviewer->updateWithPreview(point);
     }
 }
 
@@ -1541,7 +1616,10 @@ void Platform_ToolboxProxy::slotSliderPressed()
 void Platform_ToolboxProxy::slotSliderReleased()
 {
     m_bMousePree = false;
-    m_pEngine->seekAbsolute(m_pProgBar->slider()->sliderPosition());
+    if (m_mircastWidget->getMircastState() == MircastWidget::Screening)
+        m_mircastWidget->slotSeekMircast(m_pProgBar->slider()->sliderPosition());
+    else
+        m_pEngine->seekAbsolute(m_pProgBar->slider()->sliderPosition());
 }
 
 void Platform_ToolboxProxy::slotBaseMuteChanged(QString sk, const QVariant &/*val*/)
@@ -1553,10 +1631,11 @@ void Platform_ToolboxProxy::slotBaseMuteChanged(QString sk, const QVariant &/*va
 
 void Platform_ToolboxProxy::slotVolumeButtonClicked()
 {
-    if (m_pVolSlider->getsliderstate())
-        return;
     //与其他按键保持一致，工具栏隐藏时不响应
     if (!isVisible()) return;
+    m_pVolBtn->hideTip();
+    if (m_pVolSlider->getsliderstate())
+        return;
     /*
      * 设置-2为已经完成第一次打开设置音量
      * -1为初始化数值
@@ -1565,9 +1644,9 @@ void Platform_ToolboxProxy::slotVolumeButtonClicked()
     if (!m_pVolSlider->isVisible()) {
         m_pVolSlider->adjustSize();
         m_pVolSlider->show();
-        m_pVolSlider->popup();
+        m_pVolSlider->raise();
     } else {
-        m_pVolSlider->popup();
+        m_pVolSlider->hide();
     }
 }
 
@@ -1575,11 +1654,70 @@ void Platform_ToolboxProxy::slotFileLoaded()
 {
     m_pProgBar->slider()->setRange(0, static_cast<int>(m_pEngine->duration()));
     m_pProgBar_Widget->setCurrentIndex(1);
+    m_pPreviewer->setFixedSize(0, 0);
     update();
+    //正在投屏时如果当前播放为音频直接播放下一首。
+    if(m_pEngine->currFileIsAudio()&&m_mircastWidget->getMircastState() != MircastWidget::Idel) {
+        //如果全是音频文件则退出投屏
+        bool isAllAudio = true;
+        QString sNextVideoName;
+        int nNextIndex = -1;
+        QList<PlayItemInfo> lstItemInfo = m_pEngine->getplaylist()->items();
+        for(int i = 0; i < lstItemInfo.count(); i++) {
+            PlayItemInfo iteminfo = lstItemInfo.at(i);
+            if(iteminfo.mi.vCodecID != -1) {
+                isAllAudio = false;
+                if(sNextVideoName.isNull()) {
+                    sNextVideoName = iteminfo.mi.filePath;
+                    nNextIndex = i;
+                    break;
+                }
+            }
+        }
+        if(isAllAudio) {
+            m_pMainWindow->slotExitMircast();
+            return;
+        }
+        QString sCurPath = m_pEngine->getplaylist()->currentInfo().mi.filePath;
+        int nIndex = -1;
+        for(int i = 0; i < lstItemInfo.count(); i++) {
+            PlayItemInfo iteminfo = lstItemInfo.at(i);
+            if(iteminfo.mi.filePath == sCurPath) {
+                nIndex = i;
+                break;
+            }
+        }
+        if(nIndex == -1) return;
+        if(nIndex < nNextIndex && !sNextVideoName.isNull()) {
+            m_pMainWindow->play({sNextVideoName});
+        } else{
+            bool isNext = true;
+            for(int i = nIndex; i < lstItemInfo.count(); i++) {
+                PlayItemInfo iteminfo = lstItemInfo.at(i);
+                if(iteminfo.mi.vCodecID != -1) {
+                    isNext = false;
+                    m_pMainWindow->play({iteminfo.mi.filePath});
+                    break;
+                }
+            }
+            if(m_pEngine->getplaylist()->playMode() == PlaylistModel::OrderPlay) {
+                if(isNext)
+                    m_pMainWindow->slotExitMircast();
+                return;
+            }
+            if(isNext && !sNextVideoName.isNull()){
+                m_pMainWindow->play({sNextVideoName});
+            }
+        }
+        return;
+    }
+    m_mircastWidget->playNext();
 }
 
 void Platform_ToolboxProxy::slotElapsedChanged()
 {
+    if(m_mircastWidget->getMircastState() != MircastWidget::Idel)
+        return;
     quint64 url = static_cast<quint64>(-1);
     if (m_pEngine->playlist().current() != -1) {
         url = static_cast<quint64>(m_pEngine->duration());
@@ -1607,20 +1745,35 @@ void Platform_ToolboxProxy::slotPlayListStateChange(bool isShortcut)
     }
 
     closeAnyPopup();
+
+/**
+ * 此处在动画执行前设定好ToolboxProxy的起始位置和终止位置
+ * 基于 MainWindow::updateProxyGeometry 所设置的初始状态 以及 是否是紧凑模式 定位ToolboxProxy的起始位置和终止位置
+*/
+    QRect rc_view=m_pMainWindow->rect();
+    QRect rc_opened;
+    rc_opened = QRect(5, rc_view.height() - (TOOLBOX_SPACE_HEIGHT + TOOLBOX_HEIGHT) - rc_view.top() - 5,
+                      rc_view.width() - 10, (TOOLBOX_SPACE_HEIGHT + TOOLBOX_HEIGHT + 7));
+    QRect rc_closed = QRect(5, rc_view.height() - TOOLBOX_HEIGHT - rc_view.top() - 5,
+                            rc_view.width() - 10, TOOLBOX_HEIGHT);
+
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        rc_opened = QRect(5, rc_view.height() - (TOOLBOX_SPACE_HEIGHT + TOOLBOX_DSIZEMODE_HEIGHT) - rc_view.top() - 5,
+                          rc_view.width() - 10, (TOOLBOX_SPACE_HEIGHT + TOOLBOX_DSIZEMODE_HEIGHT + 7));
+        rc_closed = QRect(5, rc_view.height() - TOOLBOX_DSIZEMODE_HEIGHT - rc_view.top() - 5,
+                          rc_view.width() - 10, TOOLBOX_DSIZEMODE_HEIGHT);
+    }
+#endif
+
     if (m_pPlaylist->state() == Platform_PlaylistWidget::State::Opened) {
         //窗口绑定渲染不展示动画,故按键状态不做限制
         Q_UNUSED(isShortcut);
-        QRect rcBegin = this->geometry();
-        QRect rcEnd = rcBegin;
-        rcEnd.setY(rcBegin.y() - TOOLBOX_SPACE_HEIGHT - 7);
-        setGeometry(rcEnd);
+        setGeometry(rc_opened);
         m_pListBtn->setChecked(true);
     } else {
         Q_UNUSED(isShortcut);
-        QRect rcBegin = this->geometry();
-        QRect rcEnd = rcBegin;
-        rcEnd.setY(rcBegin.y() + TOOLBOX_SPACE_HEIGHT + 7);
-        setGeometry(rcEnd);
+        setGeometry(rc_closed);
         m_pListBtn->setChecked(false);
     }
 }
@@ -1699,6 +1852,25 @@ void Platform_ToolboxProxy::setBtnFocusSign(bool sign)
 {
     m_bSetListBtnFocus = sign;
 }
+
+bool Platform_ToolboxProxy::isInMircastWidget(const QPoint &p)
+{
+    if (!m_mircastWidget->isVisible())
+        return false;
+    return m_mircastWidget->geometry().contains(p);
+}
+
+void Platform_ToolboxProxy::updateMircastWidget(QPoint p)
+{
+    m_mircastWidget->move(p.x() - m_mircastWidget->width(), p.y() - m_mircastWidget->height() - 10);
+}
+
+void Platform_ToolboxProxy::hideMircastWidget()
+{
+    m_mircastWidget->hide();
+    m_pMircastBtn->setChecked(false);
+    m_pMircastBtn->setIcon(QIcon::fromTheme("dcc_mircast"));
+}
 /**
  * @brief volumeUp 鼠标滚轮增加音量
  */
@@ -1868,6 +2040,9 @@ void Platform_ToolboxProxy::updateButtonStates()
 
     if(m_pEngine->state() != PlayerEngine::CoreState::Idle) {
         bRawFormat = m_pEngine->getplaylist()->currentInfo().mi.isRawFormat();
+        m_pMircastBtn->setEnabled(!m_pEngine->currFileIsAudio());
+        if(m_pEngine->currFileIsAudio())
+            m_mircastWidget->setVisible(false);
         if(bRawFormat && !m_pEngine->currFileIsAudio()){                                             // 如果正在播放的视频是裸流不支持音量调节和进度调节
             m_pProgBar->setEnabled(false);
             m_pProgBar->setEnableIndication(false);
@@ -1944,9 +2119,27 @@ void Platform_ToolboxProxy::updateFullState()
     }
 }
 
+void Platform_ToolboxProxy::slotUpdateMircast(int state, QString msg)
+{
+    emit sigMircastState(state, msg);
+    if (state == 0) {
+        m_pVolBtn->setButtonEnable(false);
+        m_pFullScreenBtn->setEnabled(false);
+    } else {
+        bool bRawFormat = m_pEngine->getplaylist()->currentInfo().mi.isRawFormat();
+        if(bRawFormat && !m_pEngine->currFileIsAudio()) {
+            m_pVolBtn->setButtonEnable(false);
+        } else {
+            m_pVolBtn->setButtonEnable(true);
+        }
+        m_pFullScreenBtn->setEnabled(true);
+    }
+}
+
 void Platform_ToolboxProxy::updatePlayState()
 {
-    if (m_pEngine->state() == PlayerEngine::CoreState::Playing) {
+    if (((m_mircastWidget->getMircastState() != MircastWidget::Idel) && (m_mircastWidget->getMircastPlayState() == MircastWidget::Play))
+            || m_pEngine->state() == PlayerEngine::CoreState::Playing) {
         if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
             DPalette pa;
             pa = m_pPalyBox->palette();
@@ -1970,6 +2163,10 @@ void Platform_ToolboxProxy::updatePlayState()
             pa.setColor(DPalette::Dark, QColor(255, 255, 255, 255));
             m_pListBtn->setPalette(pa);
 
+            pa = m_pMircastBtn->palette();
+            pa.setColor(DPalette::Light, QColor(255, 255, 255, 255));
+            pa.setColor(DPalette::Dark, QColor(255, 255, 255, 255));
+            m_pMircastBtn->setPalette(pa);
         } else {
             DPalette pa;
             pa = m_pPalyBox->palette();
@@ -1992,6 +2189,11 @@ void Platform_ToolboxProxy::updatePlayState()
             pa.setColor(DPalette::Light, QColor(0, 0, 0, 255));
             pa.setColor(DPalette::Dark, QColor(0, 0, 0, 255));
             m_pListBtn->setPalette(pa);
+
+            pa = m_pMircastBtn->palette();
+            pa.setColor(DPalette::Light, QColor(0, 0, 0, 255));
+            pa.setColor(DPalette::Dark, QColor(0, 0, 0, 255));
+            m_pMircastBtn->setPalette(pa);
         }
         m_pPlayBtn->setIcon(QIcon::fromTheme("dcc_suspend", QIcon(":/icons/deepin/builtin/light/normal/suspend_normal.svg")));
         //lmh0910wayland下用这一套tooltip
@@ -2021,6 +2223,10 @@ void Platform_ToolboxProxy::updatePlayState()
             pa.setColor(DPalette::Dark, QColor(255, 255, 255, 255));
             m_pListBtn->setPalette(pa);
 
+            pa = m_pMircastBtn->palette();
+            pa.setColor(DPalette::Light, QColor(255, 255, 255, 255));
+            pa.setColor(DPalette::Dark, QColor(255, 255, 255, 255));
+            m_pMircastBtn->setPalette(pa);
         } else {
             DPalette pa;
             pa = m_pPalyBox->palette();
@@ -2044,6 +2250,11 @@ void Platform_ToolboxProxy::updatePlayState()
             pa.setColor(DPalette::Dark, QColor(0, 0, 0, 255));
             m_pListBtn->setPalette(pa);
 
+            pa = m_pMircastBtn->palette();
+            pa.setColor(DPalette::Light, QColor(0, 0, 0, 255));
+            pa.setColor(DPalette::Dark, QColor(0, 0, 0, 255));
+            m_pMircastBtn->setPalette(pa);
+
         }
         //lmh0910wayland下用这一套tooltip
         m_pPlayBtn->setToolTip(tr("Play"));
@@ -2134,6 +2345,14 @@ void Platform_ToolboxProxy::buttonClicked(QString id)
         m_nClickTime = QDateTime::currentMSecsSinceEpoch();
         m_pMainWindow->requestAction(ActionFactory::ActionKind::TogglePlaylist);
         m_pListBtn->hideToolTip();
+    } else if (id == "mircast") {
+        m_mircastWidget->togglePopup();
+        m_pMircastBtn->hideToolTip();
+        m_pMircastBtn->setChecked(m_mircastWidget->isVisible());
+        if (m_pMircastBtn->isChecked())
+            m_pMircastBtn->setIcon(QIcon(":/icons/deepin/builtin/light/checked/mircast_chenked.svg"));
+        else
+            m_pMircastBtn->setIcon(QIcon::fromTheme("dcc_mircast"));
     }
 }
 
@@ -2144,7 +2363,7 @@ void Platform_ToolboxProxy::buttonEnter()
     ToolButton *btn = qobject_cast<ToolButton *>(sender());
     QString id = btn->property("TipId").toString();
 
-    if (id == tr("sub") || id == tr("fs") || id == tr("list")) {
+    if (id == "sub" || id == "fs" || id == "list" || id == "mir") {
         updateToolTipTheme(btn);
         btn->showToolTip();
     }
@@ -2157,7 +2376,7 @@ void Platform_ToolboxProxy::buttonLeave()
     ToolButton *btn = qobject_cast<ToolButton *>(sender());
     QString id = btn->property("TipId").toString();
 
-    if (id == tr("sub") || id == tr("fs") || id == tr("list")) {
+    if (id == "sub" || id == "fs" || id == "list" || id == "mir") {
         btn->hideToolTip();
     }
 }
@@ -2203,17 +2422,6 @@ void Platform_ToolboxProxy::resizeEvent(QResizeEvent *event)
             m_pPaOpen->setDuration(0);
             m_pPaClose->setDuration(0);
         }
-        //使偏移位置与初始化偏移的位置相同
-        int widthOffset = 0;
-        if (m_pPlaylist && m_pPlaylist->state() == Platform_PlaylistWidget::State::Opened && m_bAnimationFinash == true) {
-            QRect r(widthOffset, m_pMainWindow->height() - (TOOLBOX_SPACE_HEIGHT + TOOLBOX_HEIGHT + 7) - m_pMainWindow->rect().top() - widthOffset,
-                    m_pMainWindow->rect().width() - 10, (TOOLBOX_SPACE_HEIGHT + TOOLBOX_HEIGHT + 7));
-            this->setGeometry(r);
-        } else if (m_pPlaylist && m_pPlaylist->state() == Platform_PlaylistWidget::State::Closed && m_bAnimationFinash == true) {
-            QRect r(widthOffset, m_pMainWindow->height() - TOOLBOX_HEIGHT - m_pMainWindow->rect().top() - widthOffset,
-                    m_pMainWindow->rect().width() - 10, TOOLBOX_HEIGHT);
-            this->setGeometry(r);
-        }
 
         updateTimeLabel();
     }
@@ -2245,7 +2453,8 @@ bool Platform_ToolboxProxy::eventFilter(QObject *obj, QEvent *ev)
 
     if(CompositingManager::get().platform() == Platform::X86) {
         if (obj == m_pListBtn) {
-            if (ev->type() == QEvent::MouseButtonRelease) {
+            QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(ev);
+            if (ev->type() == QEvent::MouseButtonRelease && mouseEvent->button() == Qt::RightButton) {
                 if (m_pPlaylist->state() == Platform_PlaylistWidget::State::Opened && m_pListBtn->isChecked()) {
                     m_pListBtn->setChecked(!m_pListBtn->isChecked());
                 }
@@ -2271,6 +2480,29 @@ void Platform_ToolboxProxy::updateTimeLabel()
     }
 }
 
+void Platform_ToolboxProxy::updateMircastTime(int time)
+{
+    if (m_pProgBar_Widget->currentIndex() == 1) {              //进度条模式
+
+        if (!m_pProgBar->signalsBlocked()) {
+            m_pProgBar->blockSignals(true);
+        }
+
+        m_pProgBar->slider()->setSliderPosition(time);
+        m_pProgBar->slider()->setValue(time);
+        m_pProgBar->blockSignals(false);
+    } else {
+        m_pViewProgBar->setIsBlockSignals(true);
+        m_pViewProgBar->setValue(time);
+        m_pViewProgBar->setIsBlockSignals(false);
+    }
+    quint64 url = static_cast<quint64>(-1);
+    if (m_pEngine->playlist().current() != -1) {
+        url = static_cast<quint64>(m_pEngine->duration());
+    }
+    updateTimeInfo(url, time, m_pTimeLabel, m_pTimeLabelend, true);
+}
+
 void Platform_ToolboxProxy::updateToolTipTheme(ToolButton *btn)
 {
     if (DGuiApplicationHelper::LightType == DGuiApplicationHelper::instance()->themeType()) {
@@ -2306,7 +2538,7 @@ bool Platform_ToolboxProxy::getbAnimationFinash()
 void Platform_ToolboxProxy::setVolSliderHide()
 {
     if (m_pVolSlider->isVisible()) {
-        m_pVolSlider->popup();
+        m_pVolSlider->hide();
     }
 }
 
