@@ -1,36 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     mouyuankai <mouyuankai@uniontech.com>
- *
- * Maintainer: xiepengfei <xiepengfei@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "tip.h"
 
 #include <QDebug>
@@ -46,6 +18,7 @@
 #include <DUtil>
 #include <dthememanager.h>
 #include <DLabel>
+#include <DWindowManagerHelper>
 
 DWIDGET_USE_NAMESPACE
 namespace dmr {
@@ -120,10 +93,8 @@ Tip::Tip(const QPixmap &icon, const QString &text, QWidget *parent)
     bodyShadow->setOffset(0, 2.0);
     hide();
 
-    m_pWMDBus = new QDBusInterface("com.deepin.WMSwitcher","/com/deepin/WMSwitcher","com.deepin.WMSwitcher",QDBusConnection::sessionBus());
-    QDBusReply<QString> reply = m_pWMDBus->call("CurrentWM");
-    bIsWM = reply.value().contains("deepin wm");
-    connect(m_pWMDBus, SIGNAL(WMChanged(QString)), this, SLOT(slotWMChanged(QString)));
+    bIsWM = DWindowManagerHelper::instance()->hasBlurWindow();
+    connect(DWindowManagerHelper::instance(), &DWindowManagerHelper::hasBlurWindowChanged, this, &Tip::slotWMChanged);
 }
 
 Tip::~Tip()
@@ -182,13 +153,9 @@ void Tip::setBorderColor(QColor borderColor)
     d->borderColor = borderColor;
 }
 
-void Tip::slotWMChanged(QString msg)
+void Tip::slotWMChanged()
 {
-    if (msg.contains("deepin metacity")) {
-        bIsWM = false;
-    } else {
-        bIsWM = true;
-    }
+    bIsWM = DWindowManagerHelper::instance()->hasBlurWindow();
 }
 
 void Tip::pop(QPoint center)
