@@ -1,32 +1,7 @@
-/*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 /**
  * @file 此文件中实现播放窗口工具栏相关内容
  */
@@ -55,6 +30,7 @@
 #include "thumbnail_worker.h"
 #include "slider.h"
 #include "volumeslider.h"
+#include "mircastwidget.h"
 
 namespace Dtk {
 namespace Widget {
@@ -158,6 +134,24 @@ public:
     void setPressed(bool bPressed)
     {
         m_bIsPressed = bPressed;
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        if (bPressed)
+            resize(2, 42);
+        else
+            resize(6, 42);
+    } else {
+        if (bPressed)
+            resize(2, 60);
+        else
+            resize(6, 60);
+    }
+#else
+    if (bPressed)
+        resize(2, 60);
+    else
+        resize(6, 60);
+#endif
     }
 
 protected:
@@ -203,6 +197,29 @@ protected:
 private:
     bool m_bIsPressed;    ///鼠标是否按下
 };
+//wayland下防止窗口抖动背景窗口
+class PlaylistBack: public QWidget {
+public:
+    explicit PlaylistBack(QWidget *parent = nullptr): QWidget(parent)
+    {
+        setWindowFlags(windowFlags() | Qt::FramelessWindowHint); // 设置无边框
+        setAttribute(Qt::WA_TranslucentBackground); // 设置背景透明
+    }
+protected:
+    /**
+     * @brief paintEvent 绘制事件函数
+     */
+    void paintEvent(QPaintEvent *)
+    {
+        QPainter painter(this);
+        if (DGuiApplicationHelper::DarkType == DGuiApplicationHelper::instance()->themeType()) {
+            painter.fillRect(rect(), QBrush(QColor(31, 31, 31)));
+        } else {
+            painter.fillRect(rect(), this->palette().background());
+        }
+    }
+};
+
 /**
  * @brief The ToolboxProxy class
  * 实现影院工具栏
@@ -373,6 +390,21 @@ public:
      */
     void setBtnFocusSign(bool);
 
+    bool isInMircastWidget(const QPoint &);
+
+    /**
+     * @brief updateMircastWidget 更新投屏窗口位置
+     * @param p 移动位置点
+     */
+    void updateMircastWidget(QPoint p);
+
+    void hideMircastWidget();
+
+    MircastWidget *getMircast()
+    {
+        return m_mircastWidget;
+    }
+
     VolumeSlider *volumeSlider()
     {
         return m_pVolSlider;
@@ -386,6 +418,7 @@ public:
     ToolButton *fsBtn() {return m_pFullScreenBtn;}
     VolumeButton *volBtn() {return m_pVolBtn;}
     void setThumbnailmode(bool is_thumbnailmode) {m_bThumbnailmode = is_thumbnailmode;}
+    MircastWidget *getMircastWidget() {return m_mircastWidget;}
 
 public slots:
     /**
@@ -394,10 +427,6 @@ public slots:
      * TODO(xxxpengfei)：此处窗口大小没用，请在1050前去除并梳理逻辑
      */
     void finishLoadSlot(QSize size);
-    /**
-     * @brief updateplaylisticon 切换主题时更新播放列表图标
-     */
-    void updateplaylisticon();
     /**
      * @brief setthumbnailmode 设置胶片进度条的模式
      */
@@ -407,6 +436,8 @@ public slots:
      */
     void updateFullState();
 
+    void slotUpdateMircast(int, QString);
+
 signals:
     /**
      * @brief sigVolumeChanged 音量变化返回主窗口信号
@@ -423,6 +454,8 @@ signals:
       */
     void sigUnsupported();
 
+    void sigMircastState(int, QString);
+
 protected slots:
     /**
      * @brief buttonClicked 处理信号转发器发送的信号
@@ -510,7 +543,7 @@ protected slots:
      */
     void slotApplicationStateChanged(Qt::ApplicationState e);
     /**
-     * @brief slotPlayListStateChange 播放列表状态变化槽函数
+     * @brief slotPlayListStateChange 播放列表状态变化槽函数,仅playlist_widget升起或者降下的时候被调用
      */
     void slotPlayListStateChange(bool isShortcut);
     /**
@@ -561,6 +594,9 @@ protected:
      */
     bool eventFilter(QObject *obj, QEvent *ev) override;
 
+private slots:
+    void updateMircastTime(int);
+
 private:
     /**
      * @brief setup 初始化工具栏布局
@@ -588,7 +624,7 @@ private:
 
     MainWindow *m_pMainWindow;          ///主窗口
     PlayerEngine *m_pEngine;            ///播放引擎
-    PlaylistWidget *m_pPlaylist;        ///播放列表窗口
+    PlaylistWidget *m_pPlaylist = nullptr;        ///播放列表窗口
 
     DWidget *m_pProgBarspec;             ///空白进度条窗口
     QWidget *m_pBotSpec;                 ///
@@ -608,6 +644,7 @@ private:
     DMRSlider *m_pProgBar;               ///滑动条模式进度条窗口
     ThumbnailPreview *m_pPreviewer;      ///鼠标悬停时进度条预览胶片控件
     SliderTime *m_pPreviewTime;          ///鼠标悬停时进度条预览时间控件
+    MircastWidget *m_mircastWidget;      ///投屏选项窗口
 
     ButtonBoxButton *m_pPlayBtn;        ///播放按钮
     ButtonBoxButton *m_pPrevBtn;        ///上一个按钮
@@ -616,6 +653,7 @@ private:
     VolumeButton *m_pVolBtn;             ///音量按钮
     ToolButton *m_pListBtn;              ///播放列表按钮
     ToolButton *m_pFullScreenBtn;        ///全屏按钮
+    ToolButton *m_pMircastBtn;           ///投屏按钮
 
     //lmh0910DButtonBoxButton替换到ButtonBoxButton
     ButtonToolTip *m_pPlayBtnTip;        ///播放按钮的悬浮提示
@@ -623,10 +661,13 @@ private:
     ButtonToolTip *m_pNextBtnTip;        ///下一个按钮的悬浮提示
     ButtonToolTip *m_pFullScreenBtnTip;  ///全屏按钮的悬浮提示
     ButtonToolTip *m_pListBtnTip;        ///播放列表按钮的悬浮提示
+    ButtonToolTip *m_pMircastBtnTip;
+    ButtonToolTip *m_pVolBtnTip;
 
     viewProgBarLoad *m_pWorker;          ///获取胶片的线程
     QPropertyAnimation *m_pPaOpen;       ///工具栏升起动画
     QPropertyAnimation *m_pPaClose;      ///工具栏降下动画
+    PlaylistBack *m_pListWgt = nullptr;  ///wayland播放列表背景窗口
 
     QList<QPixmap > m_pmList;
     QList<QPixmap > m_pmBlackList;
@@ -734,6 +775,8 @@ private:
 #define TOOLBOX_TOP_EXTENT  0
 #define TOOLBOX_SPACE_HEIGHT 314
 #define TOOLBOX_HEIGHT  80
+/*紧凑模式下toolbox的高度*/
+#define TOOLBOX_DSIZEMODE_HEIGHT 50
 #define TOOLBOX_HEIGHT_EXT (TOOLBOX_HEIGHT + TOOLBOX_TOP_EXTENT)
 #define TOOLBOX_BUTTON_WIDTH 50
 #define TOOLBOX_BUTTON_HEIGHT 50
