@@ -1,37 +1,10 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     mouyuankai <mouyuankai@uniontech.com>
- *
- * Maintainer: xiepengfei <xiepengfei@uniontech.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "toolbutton.h"
+#include "utils.h"
 #include <dthememanager.h>
 #include <DApplication>
 
@@ -42,6 +15,27 @@ VolumeButton::VolumeButton(QWidget *parent)
     setIcon(QIcon::fromTheme("dcc_volume"));
     setIconSize(QSize(36, 36));
     installEventFilter(this);
+    m_pToolTip = new ToolTip;
+    m_pToolTip->setText(tr("Volume"));
+
+    connect(&m_showTime, &QTimer::timeout, [=]{
+        QPoint pos = this->parentWidget()->mapToGlobal(this->pos());
+        pos.rx() = pos.x() + (this->width() - m_pToolTip->width()) / 2;
+        pos.ry() = pos.y() - 40;
+
+        if (nullptr != m_pToolTip) {
+            m_pToolTip->move(pos);
+            m_pToolTip->show();
+        }
+    });
+}
+
+void VolumeButton::hideTip()
+{
+    if (m_showTime.isActive())
+        m_showTime.stop();
+    if (m_pToolTip->isVisible())
+        m_pToolTip->hide();
 }
 
 void VolumeButton::setVolume(int nVolume)
@@ -61,7 +55,6 @@ void VolumeButton::setMute(bool bMute)
 void VolumeButton::setButtonEnable(bool bFlag)
 {
     QIcon icon = QIcon::fromTheme("dcc_volumedisable");
-
     if (bFlag) {
         setEnabled(true);
         changeStyle();
@@ -87,6 +80,8 @@ void VolumeButton::changeStyle()
 void VolumeButton::enterEvent(QEvent *ev)
 {
     emit entered();
+    if (!utils::check_wayland_env() && !m_showTime.isActive())
+        m_showTime.start(1000);
 
     DIconButton::enterEvent(ev);
 }
@@ -94,6 +89,11 @@ void VolumeButton::enterEvent(QEvent *ev)
 void VolumeButton::leaveEvent(QEvent *ev)
 {
     emit leaved();
+    m_showTime.stop();
+    if (!utils::check_wayland_env() && nullptr != m_pToolTip && m_pToolTip->isVisible()) {
+        QThread::msleep(10);
+        m_pToolTip->hide();
+    }
 
     DIconButton::leaveEvent(ev);
 }
