@@ -1,32 +1,7 @@
-/*
- * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful, but
- * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
- * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
- * NON-INFRINGEMENT.  See the GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, see <http://www.gnu.org/licenses/>.
- *
- * In addition, as a special exception, the copyright holders give
- * permission to link the code of portions of this program with the
- * OpenSSL library under certain conditions as described in each
- * individual source file, and distribute linked combinations
- * including the two.
- * You must obey the GNU General Public License in all respects
- * for all of the code used other than OpenSSL.  If you modify
- * file(s) with this exception, you may extend this exception to your
- * version of the file(s), but you are not obligated to do so.  If you
- * do not wish to do so, delete this exception statement from your
- * version.  If you delete this exception statement from all source
- * files in the program, then also delete it here.
- */
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #ifndef _DMR_TOOLBUTTON_H
 #define _DMR_TOOLBUTTON_H
 
@@ -44,8 +19,10 @@
 #include <QThread>
 #include <DArrowRectangle>
 #include <DButtonBox>
+#include <DWindowManagerHelper>
 #include <QDBusInterface>
 #include <QDBusReply>
+#include <QTimer>
 
 DWIDGET_USE_NAMESPACE
 
@@ -203,10 +180,8 @@ public:
         bodyShadow->setOffset(0, 2.0);
 //        this->setGraphicsEffect(bodyShadow);
 
-        m_pWMDBus = new QDBusInterface("com.deepin.WMSwitcher","/com/deepin/WMSwitcher","com.deepin.WMSwitcher",QDBusConnection::sessionBus());
-        QDBusReply<QString> reply = m_pWMDBus->call("CurrentWM");
-        m_bIsWM = reply.value().contains("deepin wm");
-        connect(m_pWMDBus, SIGNAL(WMChanged(QString)), this, SLOT(slotWMChanged(QString)));
+        m_bIsWM = DWindowManagerHelper::instance()->hasBlurWindow();
+        connect(DWindowManagerHelper::instance(), &DWindowManagerHelper::hasBlurWindowChanged, this, &ToolTip::slotWMChanged);
     }
     virtual ~ToolTip() {}
 
@@ -223,13 +198,9 @@ public:
     }
 
 public slots:
-    void slotWMChanged(QString msg)
+    void slotWMChanged()
     {
-        if (msg.contains("deepin metacity")) {
-            m_bIsWM = false;
-        } else {
-            m_bIsWM = true;
-        }
+        m_bIsWM = DWindowManagerHelper::instance()->hasBlurWindow();
     }
 
 
@@ -300,7 +271,6 @@ private:
     bool m_bTheme;
     ThemeTYpe m_themeType;
     QString m_strText = nullptr;
-    QDBusInterface* m_pWMDBus {nullptr};
     bool m_bIsWM {false};
 };
 
@@ -316,24 +286,29 @@ public:
         if (nullptr == m_pToolTip) {
             m_pToolTip = new ToolTip;
         }
+
+        connect(&m_showTime, &QTimer::timeout, [=]{
+            QPoint pos = this->parentWidget()->mapToGlobal(this->pos());
+            pos.rx() = pos.x() + (this->width() - m_pToolTip->width()) / 2;
+            pos.ry() = pos.y() - 40;
+
+            if (nullptr != m_pToolTip) {
+                m_pToolTip->move(pos);
+                m_pToolTip->show();
+            }
+        });
     }
 
     void showToolTip()
     {
-        QPoint pos = this->parentWidget()->mapToGlobal(this->pos());
-        pos.rx() = pos.x() + (this->width() - m_pToolTip->width()) / 2;
-        pos.ry() = pos.y() - 40;
-
-        if (nullptr != m_pToolTip) {
-            m_pToolTip->move(pos);
-            QThread::msleep(10);
-            m_pToolTip->show();
-        }
+        if (!m_showTime.isActive())
+            m_showTime.start(1000);
     }
 
     void hideToolTip()
     {
-        if (nullptr != m_pToolTip) {
+        m_showTime.stop();
+        if (nullptr != m_pToolTip && m_pToolTip->isVisible()) {
             QThread::msleep(10);
             m_pToolTip->hide();
         }
@@ -365,6 +340,7 @@ protected:
 
 private:
     ToolTip *m_pToolTip {nullptr};
+    QTimer  m_showTime;
 };
 
 class VolumeButton: public DIconButton
@@ -376,6 +352,7 @@ public:
     void setVolume(int nVolume);
     void setMute(bool bMute);
     void setButtonEnable(bool bFlag);
+    void hideTip();
 
 signals:
     void entered();
@@ -398,6 +375,8 @@ private:
     QString _name;
     int m_nVolume;
     bool m_bMute;
+    ToolTip *m_pToolTip;
+    QTimer m_showTime;
 };
 
 }
