@@ -1,23 +1,8 @@
-/*
- * Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
- *
- * Author:     zhuyuliang <zhuyuliang@uniontech.com>
- *
- * Maintainer: xiepengfei <xiepengfei@uniontech.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// Copyright (C) 2020 ~ 2021, Deepin Technology Co., Ltd. <support@deepin.org>
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
+
 #include "volumeslider.h"
 #include "toolbox_proxy.h"
 #include "dbusutils.h"
@@ -29,7 +14,7 @@ namespace dmr {
 VolumeSlider::VolumeSlider(MainWindow *mw, QWidget *parent)
     : QWidget(parent), _mw(mw)
 {
-    if (CompositingManager::get().platform() != Platform::X86)
+    if (CompositingManager::get().platform() != Platform::X86 && !utils::check_wayland_env())
         setWindowFlags(Qt::ToolTip | Qt::FramelessWindowHint);
     m_iStep = 0;
     m_bIsWheel = false;
@@ -89,12 +74,12 @@ VolumeSlider::VolumeSlider(MainWindow *mw, QWidget *parent)
     connect(DGuiApplicationHelper::instance(), &DGuiApplicationHelper::themeTypeChanged,
             this, &VolumeSlider::setThemeType);
     m_autoHideTimer.setSingleShot(true);
-    connect(&m_autoHideTimer, &QTimer::timeout, this, &VolumeSlider::popup);
+    connect(&m_autoHideTimer, &QTimer::timeout, this, &VolumeSlider::hide);
 }
 
 void VolumeSlider::initVolume()
 {
-    QTimer::singleShot(500, this, [ = ] { //延迟加载等待信号槽连接
+    QTimer::singleShot(1500, this, [ = ] { //延迟加载等待信号槽连接
         int nVolume = Settings::get().internalOption("global_volume").toInt();
         bool bMute = Settings::get().internalOption("mute").toBool();
 
@@ -114,8 +99,8 @@ QString VolumeSlider::readSinkInputPath()
 {
     QString strPath = "";
 
-    QVariant v = ApplicationAdaptor::redDBusProperty("com.deepin.daemon.Audio", "/com/deepin/daemon/Audio",
-                                                     "com.deepin.daemon.Audio", "SinkInputs");
+    QVariant v = ApplicationAdaptor::redDBusProperty("org.deepin.dde.Audio1", "/org/deepin/dde/Audio1",
+                                                     "org.deepin.dde.Audio1", "SinkInputs");
 
     if (!v.isValid())
         return strPath;
@@ -123,8 +108,8 @@ QString VolumeSlider::readSinkInputPath()
     QList<QDBusObjectPath> allSinkInputsList = v.value<QList<QDBusObjectPath> >();
 
     for (auto curPath : allSinkInputsList) {
-        QVariant nameV = ApplicationAdaptor::redDBusProperty("com.deepin.daemon.Audio", curPath.path(),
-                                                             "com.deepin.daemon.Audio.SinkInput", "Name");
+        QVariant nameV = ApplicationAdaptor::redDBusProperty("org.deepin.dde.Audio1", curPath.path(),
+                                                             "org.deepin.dde.Audio1.SinkInput", "Name");
         QString strMovie = QObject::tr("Movie");
         if (!nameV.isValid() || (!nameV.toString().contains(strMovie, Qt::CaseInsensitive) && !nameV.toString().contains("deepin movie", Qt::CaseInsensitive)))
             continue;
@@ -137,11 +122,15 @@ QString VolumeSlider::readSinkInputPath()
 
 void VolumeSlider::setMute(bool muted)
 {
+    if (m_bIsMute != muted || m_nVolume == 0) {
+        return;
+    }
+
     QString sinkInputPath = readSinkInputPath();
 
     if (!sinkInputPath.isEmpty()) {
-        QDBusInterface ainterface("com.deepin.daemon.Audio", sinkInputPath,
-                                  "com.deepin.daemon.Audio.SinkInput",
+        QDBusInterface ainterface("org.deepin.dde.Audio1", sinkInputPath,
+                                  "org.deepin.dde.Audio1.SinkInput",
                                   QDBusConnection::sessionBus());
         if (!ainterface.isValid()) {
             return;
@@ -158,7 +147,7 @@ void VolumeSlider::updatePoint(QPoint point)
 {
     QRect main_rect = _mw->rect();
     QRect view_rect = main_rect.marginsRemoved(QMargins(1, 1, 1, 1));
-    m_point = point + QPoint(view_rect.width() - (TOOLBOX_BUTTON_WIDTH * 2 + 30 + (VOLSLIDER_WIDTH - TOOLBOX_BUTTON_WIDTH) / 2),
+    m_point = point + QPoint(view_rect.width() - (TOOLBOX_BUTTON_WIDTH * 3 + 40 + (VOLSLIDER_WIDTH - TOOLBOX_BUTTON_WIDTH) / 2),
                              view_rect.height() - TOOLBOX_HEIGHT - VOLSLIDER_HEIGHT);
 }
 void VolumeSlider::popup()
@@ -166,7 +155,7 @@ void VolumeSlider::popup()
     QRect main_rect = _mw->rect();
     QRect view_rect = main_rect.marginsRemoved(QMargins(1, 1, 1, 1));
 
-    int x = view_rect.width() - (TOOLBOX_BUTTON_WIDTH * 2 + 30 + (VOLSLIDER_WIDTH - TOOLBOX_BUTTON_WIDTH) / 2);
+    int x = view_rect.width() - (TOOLBOX_BUTTON_WIDTH * 3 + 40 + (VOLSLIDER_WIDTH - TOOLBOX_BUTTON_WIDTH) / 2);
     int y = view_rect.height() - TOOLBOX_HEIGHT - VOLSLIDER_HEIGHT;
     QRect end(x, y, VOLSLIDER_WIDTH, VOLSLIDER_HEIGHT);
     QRect start = end;
@@ -216,7 +205,7 @@ void VolumeSlider::delayedHide()
     m_mouseIn = false;
     DUtil::TimerSingleShot(100, [this]() {
         if (!m_mouseIn)
-            popup();
+            hide();
     });
 }
 void VolumeSlider::changeVolume(int nVolume)
@@ -297,6 +286,7 @@ void VolumeSlider::volumeChanged(int nVolume)
 
     if (m_nVolume > 0 && m_bIsMute) {      //音量改变时改变静音状态
         changeMuteState(false);
+        setMute(false);
     }
 
     refreshIcon();
@@ -351,6 +341,20 @@ void VolumeSlider::enterEvent(QEvent *e)
 }
 void VolumeSlider::showEvent(QShowEvent *se)
 {
+    QRect main_rect = _mw->rect();
+    QRect view_rect = main_rect.marginsRemoved(QMargins(1, 1, 1, 1));
+
+    int x = view_rect.width() - (TOOLBOX_BUTTON_WIDTH * 3 + 40 + (VOLSLIDER_WIDTH - TOOLBOX_BUTTON_WIDTH) / 2);
+    int y = view_rect.height() - TOOLBOX_HEIGHT - VOLSLIDER_HEIGHT;
+#ifdef DTKWIDGET_CLASS_DSizeMode
+    if (DGuiApplicationHelper::instance()->sizeMode() == DGuiApplicationHelper::CompactMode) {
+        y = y + TOOLBOX_HEIGHT * (1- 0.66);
+        x = x + (TOOLBOX_BUTTON_WIDTH * 3 * (1 - 0.66) - 6);
+    }
+#endif
+    QRect end(x, y, VOLSLIDER_WIDTH, VOLSLIDER_HEIGHT);
+    setGeometry(end);
+
     QWidget::showEvent(se);
 }
 void VolumeSlider::leaveEvent(QEvent *e)
