@@ -2,10 +2,34 @@
 <!DOCTYPE TS>
 <TS version="2.1" language="fa">
 <context>
-    <name>Presenter</name>
+    <name>MircastShowWidget</name>
     <message>
-        <source>Volume: %1%</source>
-        <translation type="vanished">صدا %1%</translation>
+        <source>Projecting... 
+Please do not exit the Movie app during the process.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Display device</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exit Miracast</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>MircastWidget</name>
+    <message>
+        <source>Project to</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Searching for devices...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No Miracast display devices were found. Please connect the device and your computer to the same WLAN network.</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -230,6 +254,43 @@
         <source>OK</source>
         <translation type="unfinished">باشه</translation>
     </message>
+    <message>
+        <source>Decoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto select (Recommended)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hardware decoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Software decoding</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Customize</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Decode mode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Video out</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The custom decoding method needs to be restarted before it can take effect,
+and whether to restart it?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Rendering engine</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>UrlDialog</name>
@@ -474,18 +535,10 @@
         <source>Buffering...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>No device found</source>
-        <translation>دستگاهی پیدا نشد</translation>
-    </message>
     <message>
         <source>Open folder</source>
         <translation>باز کردن پوشه</translation>
     </message>
-    <message>
-        <source>All videos (%1)</source>
-        <translation>همه ویدیو ها (1%)</translation>
-    </message>
     <message>
         <source>Stereo</source>
         <translation>استریو</translation>
@@ -530,10 +583,6 @@
         <source>Speed: %1x</source>
         <translation>سرعت: x1%</translation>
     </message>
-    <message>
-        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
-        <translation>زیرنویس (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
-    </message>
     <message>
         <source>View</source>
         <translation>نما</translation>
@@ -570,10 +619,6 @@
         <source>No video file found</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Open File</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Film screenshot</source>
         <translation>عکس گرفتن از فیلم</translation>
@@ -594,10 +639,6 @@
         <source>Reading DVD files...</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>All videos (%2 %1)</source>
-        <translation type="obsolete">همه ویدیو ها (1%) {2 %1)?}</translation>
-    </message>
     <message>
         <source>4K video may be stuck</source>
         <translation type="unfinished"></translation>
@@ -630,26 +671,47 @@
         <source>Please load the video first</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>All videos (*)(%2 %1)</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Auto</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Open</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Close</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Please exit smart dock</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Cannot play the disc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to adjust the subtitle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The action is not supported in this video</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
+        <comment>All (*)</comment>
+        <translation type="unfinished">زیرنویس (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
+    </message>
+    <message>
+        <source>Connection failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Miracast disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">انصراف</translation>
+    </message>
+    <message>
+        <source>Restart</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>dmr::MovieInfo</name>
@@ -764,6 +826,10 @@
         <source>%1hz</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>%1 bps</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>dmr::MpvProxy</name>
@@ -772,6 +838,259 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>dmr::Platform_MainWindow</name>
+    <message>
+        <source>Load successfully</source>
+        <translation type="unfinished">با موفقیت بازگذاری شد</translation>
+    </message>
+    <message>
+        <source>Load failed</source>
+        <translation type="unfinished">بارگذاری ناموفق بود</translation>
+    </message>
+    <message>
+        <source>Cannot play the disc</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Parse failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Open folder</source>
+        <translation type="unfinished">باز کردن پوشه</translation>
+    </message>
+    <message>
+        <source>All (*)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Speed: %1x</source>
+        <translation type="unfinished">سرعت: x1%</translation>
+    </message>
+    <message>
+        <source>Stereo</source>
+        <translation type="unfinished">استریو</translation>
+    </message>
+    <message>
+        <source>Left channel</source>
+        <translation type="unfinished">کانال چپ</translation>
+    </message>
+    <message>
+        <source>Right channel</source>
+        <translation type="unfinished">کانال راست</translation>
+    </message>
+    <message>
+        <source>Track: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unable to adjust the subtitle</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Subtitle %1: %2s</source>
+        <translation type="unfinished">زیرنویس  %1:s2%</translation>
+    </message>
+    <message>
+        <source>delayed</source>
+        <translation type="unfinished">تعویق افتاده</translation>
+    </message>
+    <message>
+        <source>advanced</source>
+        <translation type="unfinished">پیشرفته</translation>
+    </message>
+    <message>
+        <source>Subtitle (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</source>
+        <comment>All (*)</comment>
+        <translation type="unfinished">زیرنویس (*.ass *.aqt *.jss *.gsub *.ssf *.srt *.sub *.ssa *.smi *.usf *.idx)</translation>
+    </message>
+    <message>
+        <source>View</source>
+        <translation type="unfinished">نما</translation>
+    </message>
+    <message>
+        <source>Film screenshot</source>
+        <translation type="unfinished">عکس گرفتن از فیلم</translation>
+    </message>
+    <message>
+        <source>Saved to</source>
+        <translation type="unfinished">ذخیره شده در</translation>
+    </message>
+    <message>
+        <source>The screenshot is saved</source>
+        <translation type="unfinished">اسکرین شات ذخیره شد</translation>
+    </message>
+    <message>
+        <source>Failed to save the screenshot</source>
+        <translation type="unfinished">اسکرین شات نتوانست ذخیره شود</translation>
+    </message>
+    <message>
+        <source>Taking the screenshots, please wait...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reading DVD files...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No matching online subtitles</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4K video may be stuck</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">باشه</translation>
+    </message>
+    <message>
+        <source>Order play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shuffle play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single play</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single loop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>List loop</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Buffering...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Mute</source>
+        <translation type="unfinished">بی صدا</translation>
+    </message>
+    <message>
+        <source>Volume: %1%</source>
+        <translation type="unfinished">صدا %1%</translation>
+    </message>
+    <message>
+        <source>Cannot open file or stream</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please insert a CD/DVD</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>No video file found</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please load the video first</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Please exit smart dock</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The CD/DVD has been ejected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The action is not supported in this video</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid file: %1</source>
+        <translation type="unfinished">فابل نامعتبر : 1%</translation>
+    </message>
+    <message>
+        <source>Connection failed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Miracast disconnected</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">انصراف</translation>
+    </message>
+    <message>
+        <source>Restart</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>dmr::Platform_PlayItemWidget</name>
+    <message>
+        <source>The file does not exist</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>dmr::Platform_PlaylistWidget</name>
+    <message>
+        <source>Playlist</source>
+        <translation type="unfinished">لیست پخش</translation>
+    </message>
+    <message>
+        <source>Empty</source>
+        <translation type="unfinished">خالی</translation>
+    </message>
+    <message>
+        <source>%1 videos</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>dmr::Platform_ToolboxProxy</name>
+    <message>
+        <source>Play/Pause</source>
+        <translation type="unfinished">پخش/مکث</translation>
+    </message>
+    <message>
+        <source>Previous</source>
+        <translation type="unfinished">پیشین</translation>
+    </message>
+    <message>
+        <source>Next</source>
+        <translation type="unfinished">بعدی</translation>
+    </message>
+    <message>
+        <source>Fullscreen</source>
+        <translation type="unfinished">تمام صفحه</translation>
+    </message>
+    <message>
+        <source>Playlist</source>
+        <translation type="unfinished">لیست پخش</translation>
+    </message>
+    <message>
+        <source>Exit fullscreen</source>
+        <translation type="unfinished">خروج از تمام صفحه</translation>
+    </message>
+    <message>
+        <source>Pause</source>
+        <translation type="unfinished">مکث</translation>
+    </message>
+    <message>
+        <source>Play</source>
+        <translation type="unfinished">پخش</translation>
+    </message>
+    <message>
+        <source>Miracast</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>dmr::PlayItemWidget</name>
     <message>
@@ -796,10 +1115,6 @@
 </context>
 <context>
     <name>dmr::Settings</name>
-    <message>
-        <source>%1/Movie%2.jpg</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>%1/Movie%2(%3).jpg</source>
         <translation type="unfinished"></translation>
@@ -851,10 +1166,6 @@
         <source>Next</source>
         <translation>بعدی</translation>
     </message>
-    <message>
-        <source>Subtitles</source>
-        <translation>زیرنویس ها</translation>
-    </message>
     <message>
         <source>Playlist</source>
         <translation>لیست پخش</translation>
@@ -867,26 +1178,6 @@
         <source>Play/Pause</source>
         <translation>پخش/مکث</translation>
     </message>
-    <message>
-        <source>play</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>prev</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>next</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>fs</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>list</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Exit fullscreen</source>
         <translation>خروج از تمام صفحه</translation>
@@ -896,11 +1187,18 @@
         <translation>مکث</translation>
     </message>
     <message>
-        <source>Mute</source>
-        <translation type="unfinished">بی صدا</translation>
+        <source>Miracast</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>sub</source>
+        <source>Volume</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>dmr::VolumeButton</name>
+    <message>
+        <source>Volume</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
